@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: analysis.c,v 1.242 2015/03/01 13:14:20 plm Exp $
+ * $Id: analysis.c,v 1.243 2016/05/11 21:33:08 plm Exp $
  */
 
 #include "config.h"
@@ -240,7 +240,7 @@ LuckAnalysis(const TanBoard anBoard, int n0, int n1, matchstate * pms)
     if (n0-- < n1--)            /* -- because as input n0 and n1 are dice [1..6] but in calls to LuckXX() they are array indexes [0..5] */
         swap(&n0, &n1);
 
-    if (is_init_board && n0 != n1)      /* FIXME: this fails if we return to the inital position after a few moves */
+    if (is_init_board && n0 != n1)      /* FIXME: this fails if we return to the initial position after a few moves */
         return LuckFirst(anBoard, n0, n1, &ci, &ecLuck);
     else
         return LuckNormal(anBoard, n0, n1, &ci, &ecLuck);
