@@ -16,12 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: backgammon.h,v 1.454 2015/01/25 11:27:10 plm Exp $
+ * $Id: backgammon.h,v 1.458 2015/10/08 00:34:36 mdpetch Exp $
  */
 
 #ifndef BACKGAMMON_H
 #define BACKGAMMON_H
 
+#include "common.h"
+
 #include "output.h"
 #include "analysis.h"
 #include "eval.h"
@@ -83,8 +85,8 @@ typedef struct _player {
     evalsetup esChequer;
     evalsetup esCube;
     movefilter aamf[MAX_FILTER_PLIES][MAX_FILTER_PLIES];
-    int h;
     /* For PLAYER_EXTERNAL: */
+    int h;
     char *szSocket;
 } player;
 
@@ -300,6 +302,8 @@ extern listOLD *plLastMove;
  */
 extern listOLD lMatch;
 
+extern int automaticTask;
+
 extern char *aszCopying[];
 extern const char *aszGameResult[];
 extern const char *aszLuckType[];
@@ -820,9 +824,7 @@ extern void CommandSetPriorityTimeCritical(char *);
 extern void CommandSetPrompt(char *);
 extern void CommandSetRatingOffset(char *);
 extern void CommandSetRecord(char *);
-extern void CommandSetRNGAnsi(char *);
 extern void CommandSetRNGBBS(char *);
-extern void CommandSetRNGBsd(char *);
 extern void CommandSetRNG(char *);
 extern void CommandSetRNGFile(char *);
 extern void CommandSetRNGIsaac(char *);
