@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: inc3d.h,v 1.55 2015/01/17 21:52:24 mdpetch Exp $
+ * $Id: inc3d.h,v 1.57 2015/08/02 21:22:23 plm Exp $
  */
 #ifndef INC3D_H
 #define INC3D_H
@@ -66,6 +66,8 @@
 extern int numRestrictFrames;
 extern int renderingBase;
 
+extern gboolean gtk_gl_init_success;
+
 typedef enum _BoardState {
     BOARD_CLOSED, BOARD_CLOSING, BOARD_OPENING, BOARD_OPEN
 } BoardState;
@@ -192,6 +194,8 @@ struct _Flag3d {
     float ctlpoints[S_NUMPOINTS][T_NUMPOINTS][3];
 };
 
+extern struct _Flag3d flag;
+
 /* Define relative sizes of objects from arbitrary unit .05 */
 #define base_unit .05f
 
