@@ -12,7 +12,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: common.h,v 1.31 2015/01/17 21:52:23 mdpetch Exp $
+ * $Id: common.h,v 1.33 2016/01/03 17:26:05 plm Exp $
  */
 
 /*! \file common.h
@@ -22,19 +22,20 @@
 #ifndef COMMON_H
 #define COMMON_H
 #include <math.h>
+#include "config.h"
 
-#if !_GNU_SOURCE && !defined (__attribute__)
-/*! \brief GNU C specific attributes, e.g. unused
- * // */
-#define __attribute__(X)
-#endif
 
-/*! \brief Safe double error value (and float with a cast)
+#ifndef HAVE___ATTRIBUTE__
+#define __attribute__(Spec) /* Empty */
+#endif /* HAVE___ATTRIBUTE__ */
+
+
+/*! \brief Safe error value
  */
 #if defined(HUGE_VAL)
-#define ERR_VAL (-HUGE_VAL)
+#define ERR_VAL (float)(-HUGE_VAL)
 #else
-#define ERR_VAL (-FLT_MAX)
+#define ERR_VAL (float)(-FLT_MAX)
 #endif
 
 /*! \brief Macro to extract sign
