@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: credits.sh,v 1.150 2015/01/11 15:44:36 plm Exp $
+# $Id: credits.sh,v 1.153 2016/03/02 22:23:19 plm Exp $
 # 
 
 authors=/tmp/auth.$$
@@ -64,6 +64,7 @@ Petr Kadlec,Czech
 Joern Thyssen,Danish
 Olivier Baur,French
 Achim Mueller,German
+Vangelis Skarmoutsos,Greek
 Hlynur Sigurgislason,Icelandic
 Renzo Campagna,Italian
 Yoshito Takeuchi,Japanese
@@ -259,12 +260,12 @@ cat > credits.c <<EOF
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "config.h"
+#include "common.h"
 #include <glib/gi18n.h>
 #include "credits.h"
 
 const char aszCOPYRIGHT[] = N_("Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 by Gary Wong.\n"
-                               "Copyright (C) 2015 by Gary Wong and the AUTHORS; for details type \`show version'.");
+                               "Copyright (C) 2016 by Gary Wong and the AUTHORS; for details type \`show version'.");
 
 credEntry ceAuthors[] = {
 EOF
