@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dice.c,v 1.93 2015/01/19 17:22:58 mdpetch Exp $
+ * $Id: dice.c,v 1.97 2016/04/08 05:31:05 plm Exp $
  */
 
 #include "config.h"
@@ -24,7 +24,7 @@
 #include "randomorg.h"
 
 #include <fcntl.h>
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
 #ifdef sun
 #include <gmp/gmp.h>
 #else
@@ -47,15 +47,14 @@
 #include "mt19937ar.h"
 #include "isaac.h"
 #include <glib/gstdio.h>
+#include "glib-ext.h"
 
 #if USE_GTK
 #include "gtkgame.h"
 #endif
 
 const char *aszRNG[NUM_RNGS] = {
-    "ANSI",
     N_("Blum, Blum and Shub"),
-    "BSD",
     "ISAAC",
     "MD5",
     N_("Mersenne Twister"),
@@ -65,9 +64,7 @@ const char *aszRNG[NUM_RNGS] = {
 };
 
 const char *aszRNGTip[NUM_RNGS] = {
-    N_("The rand() generator specified by ANSI C (typically linear congruential)"),
     N_("Blum, Blum and Shub's verifiably strong generator"),
-    N_("The random() non-linear additive feedback generator from 4.3 BSD Unix"),
     N_("Bob Jenkins' Indirection, Shift, Accumulate, Add and Count " "cryptographic generator"),
     N_("A generator based on the Message Digest 5 algorithm"),
     N_("Makoto Matsumoto and Takuji Nishimura's generator"),
@@ -93,11 +90,11 @@ struct _rngcontext {
 
     /* RNG_MERSENNE */
     int mti;
-    unsigned long mt[N];
+    unsigned long mt[MT_ARRAY_N];
 
     /* RNG_BBS */
 
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
     mpz_t zModulus, zSeed, zZero, zOne;
     int fZInit;
 #endif                          /* HAVE_LIBGMP */
@@ -105,7 +102,7 @@ struct _rngcontext {
 
     /* common */
     unsigned long c;            /* counter */
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
     mpz_t nz;                   /* seed */
 #endif
     unsigned int n;             /* seed */
@@ -117,7 +114,7 @@ static unsigned int
  ReadDiceFile(rngcontext * rngctx);
 
 
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
 
 static void
 InitRNGBBS(rngcontext * rngctx)
@@ -349,13 +346,6 @@ PrintRNGCounter(const rng rngx, rngcontext * rngctx)
 {
 
     switch (rngx) {
-    case RNG_ANSI:
-    case RNG_BSD:
-        g_print(_("Number of calls since last seed: %lu."), rngctx->c);
-        g_print("\n");
-        g_print(_("This number may not be correct if the same " "RNG is used for rollouts and interactive play."));
-        g_print("\n");
-        break;
 
     case RNG_BBS:
     case RNG_ISAAC:
@@ -383,7 +373,7 @@ PrintRNGCounter(const rng rngx, rngcontext * rngctx)
 }
 
 
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
 
 static void
 PrintRNGSeedMP(mpz_t n)
@@ -416,7 +406,7 @@ PrintRNGSeed(const rng rngx, rngcontext * rngctx)
 
     switch (rngx) {
     case RNG_BBS:
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
         {
             char *pch;
 
@@ -448,16 +438,7 @@ PrintRNGSeed(const rng rngx, rngcontext * rngctx)
 
     case RNG_ISAAC:
     case RNG_MERSENNE:
-#if HAVE_LIBGMP
-        PrintRNGSeedMP(rngctx->nz);
-#else
-        PrintRNGSeedNormal(rngctx->n);
-#endif
-        return;
-
-    case RNG_BSD:
-    case RNG_ANSI:
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
         PrintRNGSeedMP(rngctx->nz);
 #else
         PrintRNGSeedNormal(rngctx->n);
@@ -479,12 +460,9 @@ InitRNGSeed(unsigned int n, const rng rngx, rngcontext * rngctx)
     rngctx->c = 0;
 
     switch (rngx) {
-    case RNG_ANSI:
-        srand(n);
-        break;
 
     case RNG_BBS:
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
         g_assert(rngctx->fZInit);
         mpz_set_ui(rngctx->zSeed, (unsigned long) n);
         BBSCheckInitialSeed(rngctx);
@@ -493,14 +471,6 @@ InitRNGSeed(unsigned int n, const rng rngx, rngcontext * rngctx)
         abort();
 #endif
 
-    case RNG_BSD:
-#if HAVE_RANDOM
-        srandom(n);
-        break;
-#else
-        abort();
-#endif
-
     case RNG_ISAAC:{
             int i;
 
@@ -532,7 +502,7 @@ InitRNGSeed(unsigned int n, const rng rngx, rngcontext * rngctx)
     }
 }
 
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
 static void
 InitRNGSeedMP(mpz_t n, rng rng, rngcontext * rngctx)
 {
@@ -544,20 +514,20 @@ InitRNGSeedMP(mpz_t n, rng rng, rngcontext * rngctx)
 
     case RNG_MERSENNE:{
             gint32 *achState;
-            unsigned long tempmtkey[N];
+            unsigned long tempmtkey[MT_ARRAY_N];
             size_t cb;
             unsigned int i;
 
             if (mpz_cmp_ui(n, UINT_MAX) > 0) {
 
                 achState = mpz_export(NULL, &cb, -1, sizeof(gint32), 0, 0, n);
-                for (i = 0; i < N && i < cb; i++) {
+                for (i = 0; i < MT_ARRAY_N && i < cb; i++) {
                     tempmtkey[i] = achState[i];
                 }
-                for (; i < N; i++) {
+                for (; i < MT_ARRAY_N; i++) {
                     tempmtkey[i] = 0;
                 }
-                init_by_array(tempmtkey, N, &rngctx->mti, rngctx->mt);
+                init_by_array(tempmtkey, MT_ARRAY_N, &rngctx->mti, rngctx->mt);
 
                 free(achState);
             } else {
@@ -565,8 +535,6 @@ InitRNGSeedMP(mpz_t n, rng rng, rngcontext * rngctx)
             }
             break;
         }
-    case RNG_ANSI:
-    case RNG_BSD:
     case RNG_MD5:
         InitRNGSeed((unsigned int) (mpz_get_ui(n) % UINT_MAX), rng, rngctx);
         break;
@@ -654,7 +622,7 @@ RNGSystemSeed(const rng rngx, void *p, unsigned long *pnSeed)
     rngcontext *rngctx = (rngcontext *) p;
     unsigned int n = 0;
 
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
 #if !defined(WIN32)
     int h;
 #endif
@@ -698,7 +666,7 @@ RNGSystemSeed(const rng rngx, void *p, unsigned long *pnSeed)
 
     }
 #else
-#if !defined(WIN32)             /* HAVE_LIBGMP */
+#if !defined(WIN32)
     int h;
     if ((h = open("/dev/urandom", O_RDONLY)) >= 0) {
         f = read(h, &n, sizeof n) == sizeof n;
@@ -715,7 +683,7 @@ RNGSystemSeed(const rng rngx, void *p, unsigned long *pnSeed)
     }
 
     InitRNGSeed(n, rngx, rngctx);
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
     mpz_set_ui(rngctx->nz, (unsigned long) n);
 #endif
 
@@ -729,7 +697,7 @@ RNGSystemSeed(const rng rngx, void *p, unsigned long *pnSeed)
 extern void
 free_rngctx(rngcontext * rngctx)
 {
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
     mpz_clear(rngctx->nz);
 #endif
     g_free(rngctx);
@@ -744,9 +712,9 @@ InitRNG(unsigned long *pnSeed, int *pfInitFrom, const int fSet, const rng rngx)
     /* misc. initialisation */
 
     /* Mersenne-Twister */
-    rngctx->mti = N + 1;
+    rngctx->mti = MT_ARRAY_N + 1;
 
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
     /* BBS */
     rngctx->fZInit = FALSE;
     mpz_init(rngctx->nz);
@@ -771,24 +739,15 @@ extern int
 RollDice(unsigned int anDice[2], rng * prng, rngcontext * rngctx)
 {
     unsigned long tmprnd;
-    const unsigned long rand_max_q = RAND_MAX / 6;
-    const unsigned long rand_max_l = rand_max_q * 6;
     const unsigned long exp232_q = 715827882;
     const unsigned long exp232_l = 4294967292U;
 
     anDice[0] = anDice[1] = 0;
 
     switch (*prng) {
-    case RNG_ANSI:
-        while ((tmprnd = rand()) >= rand_max_l);        /* Try again */
-        anDice[0] = 1 + (unsigned int) (tmprnd / rand_max_q);
-        while ((tmprnd = rand()) >= rand_max_l);
-        anDice[1] = 1 + (unsigned int) (tmprnd / rand_max_q);
-        rngctx->c += 2;
-        break;
 
     case RNG_BBS:
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
         if (BBSCheck(rngctx)) {
             BBSInitialSeedFailure(rngctx);
             break;
@@ -801,18 +760,6 @@ RollDice(unsigned int anDice[2], rng * prng, rngcontext * rngctx)
         abort();
 #endif
 
-    case RNG_BSD:
-#if HAVE_RANDOM
-        while ((tmprnd = random()) >= rand_max_l);      /* Try again */
-        anDice[0] = 1 + (unsigned int) (tmprnd / rand_max_q);
-        while ((tmprnd = random()) >= rand_max_l);
-        anDice[1] = 1 + (unsigned int) (tmprnd / rand_max_q);
-        rngctx->c += 2;
-        break;
-#else
-        abort();
-#endif
-
     case RNG_ISAAC:
         while ((tmprnd = irand(&rngctx->rc)) >= exp232_l);      /* Try again */
         anDice[0] = 1 + (unsigned int) (tmprnd / exp232_q);
@@ -887,7 +834,7 @@ OpenDiceFile(rngcontext * rngctx, const char *sz)
     g_free(rngctx->szDiceFilename);     /* initialized to NULL */
     rngctx->szDiceFilename = g_strdup(sz);
 
-    return (rngctx->fDice = g_fopen(sz, "r"));
+    return (rngctx->fDice = gnubg_g_fopen(sz, "r"));
 }
 
 extern void
