@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dice.h,v 1.32 2013/06/16 02:16:10 mdpetch Exp $
+ * $Id: dice.h,v 1.34 2016/04/08 05:31:05 plm Exp $
  */
 
 #ifndef DICE_H
@@ -25,7 +25,7 @@
 #include <stdio.h>
 
 typedef enum _rng {
-    RNG_ANSI, RNG_BBS, RNG_BSD, RNG_ISAAC, RNG_MD5, RNG_MERSENNE,
+    RNG_BBS, RNG_ISAAC, RNG_MD5, RNG_MERSENNE,
     RNG_MANUAL, RNG_RANDOM_DOT_ORG, RNG_FILE,
     NUM_RNGS
 } rng;
@@ -51,7 +51,7 @@ extern int RNGSystemSeed(const rng rngx, void *p, unsigned long *pnSeed);
 
 extern int RollDice(unsigned int anDice[2], rng * prngx, rngcontext * rngctx);
 
-#if HAVE_LIBGMP
+#if defined(HAVE_LIBGMP)
 extern int InitRNGSeedLong(char *sz, rng rng, rngcontext * rngctx);
 extern int InitRNGBBSModulus(const char *sz, rngcontext * rngctx);
 extern int InitRNGBBSFactors(char *sz0, char *sz1, rngcontext * rngctx);
