@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: drawboard.c,v 1.72 2015/02/01 21:48:42 plm Exp $
+ * $Id: drawboard.c,v 1.76 2015/08/02 22:09:31 mdpetch Exp $
  */
 
 #include "config.h"
@@ -913,10 +913,12 @@ extern char *
 FIBSBoard(char *pch, TanBoard anBoard, int fRoll,
           const char *szPlayer, const char *szOpp, int nMatchTo,
           int nScore, int nOpponent, int nDice0, int nDice1,
-          int nCube, int fCubeOwner, int fDoubled, int fTurn, int fCrawford, int nChequers)
+          int nCube, int fCubeOwner, int fDoubled, int fTurn, int fCrawford, int nChequers, 
+          int fPostCrawford)
 {
     char *sz = pch;
     int i, anOff[2];
+    /* int fNonCrawford = !(!fPostCrawford && (nScore == nMatchTo - 1 || nOpponent == nMatchTo - 1));*/
 
     /* Names and match length/score */
     strcpy(sz, "board:");
@@ -955,6 +957,16 @@ FIBSBoard(char *pch, TanBoard anBoard, int fRoll,
             fTurn < 0 || fCubeOwner != 0, fTurn < 0 || fCubeOwner != 1,
             fDoubled ? (fTurn ? -1 : 1) : 0, anOff[1], anOff[0], fCrawford);
 
+/*  Temporarily remove this code as it breaks the GUI by preventing a player
+    from hitting an opponents blot. It appears to the user as an illegal play
+    Reported by Wolfgang Nelles
+
+    sprintf(strchr(sz, 0), "%d:%d:%d:%d:%d:%d:%d:%d:1:-1:%d:%d:%d:%d:0:0:0:"
+            "0:%d:0", nDice0, nDice1, nDice0, nDice1, fTurn < 0 ? 1 : nCube,
+            fTurn < 0 || fCubeOwner != 0, fTurn < 0 || fCubeOwner != 1,
+            fDoubled ? (fTurn ? -1 : 1) : 0, fNonCrawford, fPostCrawford,
+            anOff[1], anOff[0], fCrawford);*/
+
     return pch;
 }
 
