@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: export.c,v 1.82 2015/04/12 22:00:25 plm Exp $
+ * $Id: export.c,v 1.86 2015/08/28 22:31:09 plm Exp $
  */
 
 #include "config.h"
@@ -27,6 +27,7 @@
 #include <glib/gprintf.h>
 #include <stdlib.h>
 #include <string.h>
+#include "glib-ext.h"
 
 #if HAVE_LIBPNG
 #include <png.h>
@@ -469,7 +470,7 @@ WritePNG(const char *sz, unsigned char *puch, unsigned int nStride, unsigned int
     png_text atext[3];
     unsigned int i;
 
-    if (!(pf = g_fopen(sz, "wb")))
+    if (!(pf = gnubg_g_fopen(sz, "wb")))
         return -1;
 
     if (!(ppng = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL))) {
@@ -796,7 +797,7 @@ CommandExportPositionSnowieTxt(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -851,7 +852,7 @@ CommandExportPositionJF(char *sz)
 
     if (!strcmp(sz, "-"))
         fp = stdout;
-    else if (!(fp = g_fopen(sz, "wb"))) {
+    else if (!(fp = gnubg_g_fopen(sz, "wb"))) {
         outputerr(sz);
         return;
     }
@@ -1046,8 +1047,7 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
                 fprintf(pf, " %-31s%s\n", ap[0].szName, ap[1].szName);
             msExport.fCubeOwner = -1;
             /* FIXME what about automatic doubles? */
-            continue;
-            break;
+            continue;	/* branch out of the switch and continue for (pl ...) */
         case MOVE_NORMAL:
             diceRolled = 0;
             sprintf(sz, "%u%u: ", pmr->anDice[0], pmr->anDice[1]);
@@ -1196,7 +1196,7 @@ ExportGameGam(char *sz, int fSst)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -1248,7 +1248,7 @@ ExportMatchMat(char *sz, int fSst)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -1275,7 +1275,13 @@ ExportMatchMat(char *sz, int fSst)
         case VARIATION_HYPERGAMMON_3:
             fprintf(pf, "; [Variation \"HyperGammon (3)\"]\n");
             break;
+        case VARIATION_STANDARD:
+            break;
+        default:
+            g_assert_not_reached();
+            break;
         }
+
         if (mi.pchAnnotator)
             fprintf(pf, "; [Transcriber \"%s\"]\n", mi.pchAnnotator);
         if (mi.pchComment) {
