@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkboard.h,v 1.101 2013/06/16 02:16:13 mdpetch Exp $
+ * $Id: gtkboard.h,v 1.103 2015/12/04 23:07:52 plm Exp $
  */
 
 #ifndef GTKBOARD_H
@@ -29,7 +29,7 @@
 #include "common.h"
 #include "render.h"
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
 #include "types3d.h"
 #endif
 
@@ -111,7 +111,7 @@ struct _BoardData {
     int iTargetHelpPoints[4];   /* Drag target position */
     int grayBoard;              /* Show board grayed when editing */
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     BoardData3d *bd3d;          /* extra members for 3d board */
 #endif
     renderdata *rd;             /* The board colour settings */
@@ -165,14 +165,7 @@ enum TheoryTypes { TT_PIPCOUNT = 1, TT_EPC = 2, TT_RETURNHITS = 4, TT_KLEINCOUNT
 void UpdateTheoryData(BoardData * bd, int UpdateTypes, const TanBoard points);
 
 extern void read_board(BoardData * bd, TanBoard points);
-extern void update_gnubg_id(BoardData * bd, const TanBoard points);
 extern void update_pipcount(BoardData * bd, const TanBoard points);
-extern void write_board(BoardData * bd, TanBoard anBoard);
-extern void board_beep(BoardData * bd);
-extern void Confirm(BoardData * bd);
-extern int update_move(BoardData * bd);
-extern gboolean place_chequer_or_revert(BoardData * bd, int dest);
-extern gboolean LegalDestPoints(BoardData * bd, int iDestPoints[4]);
 extern void InitBoardData(BoardData * bd);
 extern gboolean board_button_press(GtkWidget * board, GdkEventButton * event, BoardData * bd);
 extern gboolean board_motion_notify(GtkWidget * widget, GdkEventMotion * event, BoardData * bd);
@@ -180,8 +173,6 @@ extern gboolean board_button_release(GtkWidget * board, GdkEventButton * event,
 extern void RollDice2d(BoardData * bd);
 extern void DestroyPanel(gnubgwindow window);
 extern void
-
-
 DrawDie(GdkDrawable * pd,
         unsigned char *achDice[2], unsigned char *achPip[2],
         const int s, GdkGC * gc, int x, int y, int fColour, int n, int alpha);
