@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkgame.h,v 1.154 2013/09/13 19:32:30 plm Exp $
+ * $Id: gtkgame.h,v 1.158 2016/01/11 21:36:30 plm Exp $
  */
 
 #ifndef GTKGAME_H
@@ -24,12 +24,13 @@
 
 #include <gtk/gtk.h>
 #include "backgammon.h"
+#include "gtkwindows.h"
 #include "gtkpanels.h"
 #include "gtkchequer.h"
 
 #define TOOLBAR_ACTION_OFFSET 10000
 
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
 extern GtkUIManager *puim;
 #endif
 
@@ -136,7 +137,7 @@ extern void GTKShowScoreSheet(void);
 extern void GTKShowVersion(void);
 extern void GTKSuspendInput(void);
 extern void GTKTextToClipboard(const char *sz);
-extern void GTKTextWindow(const char *szOutput, const char *title, const int type, GtkWidget * parent);
+extern void GTKTextWindow(const char *szOutput, const char *title, const dialogtype type, GtkWidget * parent);
 extern void GTKThaw(void);
 extern void HideAllPanels(gpointer p, guint n, GtkWidget * pw);
 extern void HintDoubleClick(GtkTreeView * treeview, GtkTreePath * path, GtkTreeViewColumn * col, hintdata * phd);
@@ -164,7 +165,7 @@ extern void ShowList(char *asz[], const char *szTitle, GtkWidget * parent);
 extern void ShowMove(hintdata * phd, const int f);
 extern void SwapBoardToPanel(int ToPanel, int updateEvents);
 extern void DoHideAllPanels(int updateEvents);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
 extern void ToggleEdit(GtkToggleAction * action, gpointer user_data);
 extern void ToggleClockwise(GtkToggleAction * action, gpointer user_data);
 extern void ToggleDockPanels(GtkToggleAction * action, gpointer user_data);
@@ -177,14 +178,14 @@ extern void ShowToolbar(void);
 extern void HideToolbar(void);
 extern void MoveListDestroy(void);
 
-#if HAVE_LIBREADLINE
+#if defined(HAVE_LIB_READLINE)
 extern int fReadingCommand;
 extern void ProcessInput(char *sz);
 #endif
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
 extern void SetSwitchModeMenuText(void);
-extern gboolean gtk_gl_init_success;
+#include "inc3d.h"
 #endif
 
 #endif
