@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkoptions.c,v 1.115 2014/07/20 21:09:28 plm Exp $
+ * $Id: gtkoptions.c,v 1.119 2016/01/31 12:56:01 plm Exp $
  */
 
 #include "config.h"
@@ -42,7 +42,7 @@
 #include "renderprefs.h"
 #include "gtkwindows.h"
 #include "openurl.h"
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
 #include "fun3d.h"
 #endif
 #include "multithread.h"
@@ -121,7 +121,6 @@ typedef struct _optionswidget {
 } optionswidget;
 
 typedef struct _SoundDetail {
-    int Enabled;
     char *Path;
 } SoundDetail;
 
@@ -138,7 +137,7 @@ static GtkWidget *soundBeepIllegal;
 static GtkWidget *soundsEnabled;
 static GtkWidget *soundList;
 static GtkWidget *pwSoundCommand;
-static int selSound;
+static gnubgsound selSound;
 static int SoundSkipUpdate;
 static int relPage, relPageActivated;
 
@@ -209,8 +208,8 @@ SoundDefaultClicked(GtkWidget * UNUSED(widget), gpointer UNUSED(userdata))
 static void
 SoundAllDefaultClicked(GtkWidget * UNUSED(widget), gpointer UNUSED(userdata))
 {
-    int i;
-    for (i = 0; i < NUM_SOUNDS; i++) {
+    gnubgsound i;
+    for (i = (gnubgsound)0; i < NUM_SOUNDS; i++) {
         g_free(soundDetails[i].Path);
         soundDetails[i].Path = GetDefaultSoundFile(i);
     }
@@ -263,7 +262,7 @@ SoundSelected(GtkTreeView * treeview, gpointer UNUSED(userdata))
 {
     GtkTreePath *path;
     gtk_tree_view_get_cursor(GTK_TREE_VIEW(treeview), &path, NULL);
-    selSound = gtk_tree_path_get_indices(path)[0];
+    selSound = (gnubgsound) gtk_tree_path_get_indices(path)[0];
 
     gtk_frame_set_label(GTK_FRAME(soundFrame), sound_description[selSound]);
     SoundSkipUpdate = TRUE;
@@ -738,7 +737,7 @@ append_display_options(optionswidget * pow)
     pw = gtk_label_new(_("Number of digits in output:"));
     gtk_box_pack_start(GTK_BOX(pwhbox), pw, FALSE, FALSE, 0);
 
-    pow->padjDigits = GTK_ADJUSTMENT(gtk_adjustment_new(1, 0, 6, 1, 1, 0));
+    pow->padjDigits = GTK_ADJUSTMENT(gtk_adjustment_new(1, 0, MAX_OUTPUT_DIGITS, 1, 1, 0));
     pow->pwDigits = gtk_spin_button_new(GTK_ADJUSTMENT(pow->padjDigits), 1, 0);
     gtk_box_pack_start(GTK_BOX(pwhbox), pow->pwDigits, TRUE, TRUE, 0);
     gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(pow->pwDigits), TRUE);
@@ -836,7 +835,7 @@ append_sound_options(optionswidget * pow)
     GtkWidget *pwhbox;
     GtkWidget *pwvboxDetails;
     GtkWidget *pwLabel;
-    gint i;
+    gnubgsound i;
     GtkTreeIter iter;
     GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
     GtkListStore *store = gtk_list_store_new(1, G_TYPE_STRING);
@@ -868,7 +867,7 @@ append_sound_options(optionswidget * pow)
                                 _("Have GNU Backgammon make " "sound effects when various events occur."));
     g_signal_connect(G_OBJECT(soundsEnabled), "toggled", G_CALLBACK(SoundToggled), NULL);
 #define SOUND_COL 0
-    for (i = 0; i < NUM_SOUNDS; i++) {
+    for (i = (gnubgsound) 0; i < NUM_SOUNDS; i++) {
         /* Copy sound path data to be used in dialog */
         soundDetails[i].Path = GetSoundFile(i);
 
@@ -941,17 +940,13 @@ append_dice_options(optionswidget * pow)
     GtkWidget *pwp, *pwvbox, *pwhbox, *pwvbox2, *pwvbox3, *pw, *frame;
     unsigned int i;
     unsigned long nRandom;
+#if defined(HAVE_LIBGMP)
     int blumblum = TRUE;
-    int bsd = TRUE;
+#else
+    int blumblum = FALSE;
+#endif
     int rngsAdded = 0, rngSelected = -1;
 
-#if !HAVE_LIBGMP
-    blumblum = FALSE;
-#endif
-#if !HAVE_RANDOM
-    bsd = FALSE;
-#endif
-
     InitRNG(&nRandom, NULL, FALSE, rngCurrent);
 
     pwp = gtk_alignment_new(0, 0, 0, 0);
@@ -1016,7 +1011,7 @@ append_dice_options(optionswidget * pow)
 
             }
 
-            if (!((i == RNG_BSD && !bsd) || (i == RNG_BBS && !blumblum))) {
+            if (!(i == RNG_BBS && !blumblum)) {
                 gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(pow->pwRngComboBox), aszRNG[i]);
                 if (i == rngCurrent)
                     rngSelected = rngsAdded;
@@ -1221,7 +1216,7 @@ append_other_options(optionswidget * pow)
                                   "Increasing the size may help evaluations "
                                   "complete more quickly, but decreasing " "the size will use less memory."));
 
-#if USE_MULTITHREAD
+#if defined(USE_MULTITHREAD)
     pwev = gtk_event_box_new();
     gtk_event_box_set_visible_window(GTK_EVENT_BOX(pwev), FALSE);
     gtk_box_pack_start(GTK_BOX(pwvbox), pwev, FALSE, FALSE, 0);
@@ -1311,12 +1306,12 @@ static int checkupdate_n;
 static void
 SetSoundSettings(void)
 {
-    int i;
+    gnubgsound i;
     outputoff();
     fGUIBeep = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(soundBeepIllegal));
     CHECKUPDATE(soundBeepIllegal, fGUIBeep, "set gui beep %s");
     CHECKUPDATE(soundsEnabled, fSound, "set sound enable %s");
-    for (i = 0; i < NUM_SOUNDS; i++) {
+    for (i = (gnubgsound)0; i < NUM_SOUNDS; i++) {
         if (*soundDetails[i].Path)
             SetSoundFile(i, soundDetails[i].Path);
         else
@@ -1330,14 +1325,12 @@ static void
 OptionsOK(GtkWidget * pw, optionswidget * pow)
 {
     char sz[128];
-    unsigned int n;
-    unsigned int i;
+    int n;
+    unsigned int u, i;
     gchar *filename, *command, *tmp, *newfolder;
     const gchar *new_browser;
     static const char *set_rng_cmds[NUM_RNGS] = {
-        "set rng ansi",
         "set rng bbs",
-        "set rng bsd",
         "set rng isaac",
         "set rng md5",
         "set rng mersenne",
@@ -1401,8 +1394,8 @@ OptionsOK(GtkWidget * pw, optionswidget * pow)
         CHECKUPDATE(pow->pwOutputGWC, fOutputWinPC, "set output winpc %s")
         CHECKUPDATE(pow->pwOutputMWCpst, fOutputMatchPC, "set output matchpc %s")
 
-        if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjDigits)) != fOutputDigits) {
-        sprintf(sz, "set output digits %u", n);
+        if ((n = (int) gtk_adjustment_get_value(pow->padjDigits)) != fOutputDigits) {
+        sprintf(sz, "set output digits %d", n);
         UserCommand(sz);
     }
 
@@ -1412,18 +1405,18 @@ OptionsOK(GtkWidget * pw, optionswidget * pow)
     CHECKUPDATE(pow->pwConfStart, fConfirmNew, "set confirm new %s")
         CHECKUPDATE(pow->pwConfOverwrite, fConfirmSave, "set confirm save %s")
 
-        if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjCubeAutomatic)) != cAutoDoubles) {
-        sprintf(sz, "set automatic doubles %u", n);
+        if ((u = (unsigned int) gtk_adjustment_get_value(pow->padjCubeAutomatic)) != cAutoDoubles) {
+        sprintf(sz, "set automatic doubles %u", u);
         UserCommand(sz);
     }
 
-    if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjCubeBeaver)) != nBeavers) {
-        sprintf(sz, "set beavers %u", n);
+    if ((u = (unsigned int) gtk_adjustment_get_value(pow->padjCubeBeaver)) != nBeavers) {
+        sprintf(sz, "set beavers %u", u);
         UserCommand(sz);
     }
 
-    if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjLength)) != nDefaultLength) {
-        sprintf(sz, "set matchlength %u", n);
+    if ((u = (unsigned int) gtk_adjustment_get_value(pow->padjLength)) != nDefaultLength) {
+        sprintf(sz, "set matchlength %u", u);
         UserCommand(sz);
     }
 
@@ -1455,12 +1448,12 @@ OptionsOK(GtkWidget * pw, optionswidget * pow)
     CHECKUPDATE(pow->pwRecordGames, fRecord, "set record %s")
         CHECKUPDATE(pow->pwDisplay, fDisplay, "set display %s")
 
-        if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjCache)) != GetEvalCacheSize()) {
-        SetEvalCacheSize(n);
+        if ((u = (unsigned int) gtk_adjustment_get_value(pow->padjCache)) != GetEvalCacheSize()) {
+        SetEvalCacheSize(u);
     }
-#if USE_MULTITHREAD
-    if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjThreads)) != MT_GetNumThreads()) {
-        sprintf(sz, "set threads %u", n);
+#if defined(USE_MULTITHREAD)
+    if ((u = (unsigned int) gtk_adjustment_get_value(pow->padjThreads)) != MT_GetNumThreads()) {
+        sprintf(sz, "set threads %u", u);
         UserCommand(sz);
     }
 #endif
@@ -1474,14 +1467,14 @@ OptionsOK(GtkWidget * pw, optionswidget * pow)
     CHECKUPDATE(pow->pwAutoSaveRollout, fAutoSaveRollout, "set autosave rollout %s");
     CHECKUPDATE(pow->pwAutoSaveConfirmDelete, fAutoSaveConfirmDelete, "set autosave confirm %s");
 
-    if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjDelay)) != nDelay) {
-        sprintf(sz, "set delay %u", n);
+    if ((u = (unsigned int) gtk_adjustment_get_value(pow->padjDelay)) != nDelay) {
+        sprintf(sz, "set delay %u", u);
         UserCommand(sz);
     }
 
     if (pow->fChanged == 1) {
-        n = (unsigned int) gtk_adjustment_get_value(pow->padjSeed);
-        sprintf(sz, "set seed %u", n);
+        u = (unsigned int) gtk_adjustment_get_value(pow->padjSeed);
+        sprintf(sz, "set seed %u", u);
         UserCommand(sz);
     }
 
@@ -1494,7 +1487,7 @@ OptionsOK(GtkWidget * pw, optionswidget * pow)
         CHECKUPDATE(pow->pwSetWindowPos, fGUISetWindowPos, "set gui windowpositions %s")
         CHECKUPDATE(pow->pwGrayEdit, fGUIGrayEdit, "set gui grayedit %s")
         CHECKUPDATE(pow->pwDragTargetHelp, fGUIDragTargetHelp, "set gui dragtargethelp %s") {
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
         if (display_is_3d(bd->rd))
             updateDiceOccPos(bd, bd->bd3d);
         else
@@ -1536,8 +1529,8 @@ OptionsOK(GtkWidget * pw, optionswidget * pow)
              && animGUI != ANIMATE_SLIDE)
         UserCommand("set gui animation slide");
 
-    if ((n = (unsigned int) gtk_adjustment_get_value(pow->padjSpeed)) != nGUIAnimSpeed) {
-        sprintf(sz, "set gui animation speed %u", n);
+    if ((u = (unsigned int) gtk_adjustment_get_value(pow->padjSpeed)) != nGUIAnimSpeed) {
+        sprintf(sz, "set gui animation speed %u", u);
         UserCommand(sz);
     }
 
@@ -1545,15 +1538,15 @@ OptionsOK(GtkWidget * pw, optionswidget * pow)
 
     n = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pow->pwCheat));
 
-    if ((int) n != fCheat) {
+    if (n != fCheat) {
         sprintf(sz, "set cheat enable %s", n ? "on" : "off");
         UserCommand(sz);
     }
 
     for (i = 0; i < 2; ++i) {
-        n = gtk_combo_box_get_active(GTK_COMBO_BOX(pow->apwCheatRoll[i]));
-        if (n != afCheatRoll[i]) {
-            sprintf(sz, "set cheat player %u roll %d", i, n + 1);
+        u = gtk_combo_box_get_active(GTK_COMBO_BOX(pow->apwCheatRoll[i]));
+        if (u != afCheatRoll[i]) {
+            sprintf(sz, "set cheat player %u roll %u", i, u + 1);
             UserCommand(sz);
         }
     }
