@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrelational.c,v 1.40 2013/06/16 02:16:16 mdpetch Exp $
+ * $Id: gtkrelational.c,v 1.44 2016/05/14 22:28:32 plm Exp $
  */
 
 #include "config.h"
@@ -47,7 +47,7 @@ enum {
     NUM_COLUMNS
 };
 
-static gchar *titles[] = {
+static const gchar *titles[] = {
     N_("Nick"),
     N_("Gnu\nErr"),
     N_("Gnu\nMove"),
@@ -70,13 +70,13 @@ static GtkWidget *pwQueryText;
 static GtkWidget *pwQueryResult = NULL;
 static GtkWidget *pwQueryBox;
 
-GtkListStore *playerStore;
-GtkListStore *dbStore;
-GtkTreeIter selected_iter;
-int optionsValid;
-GtkWidget *playerTreeview, *adddb, *deldb, *gameStats, *dbList, *dbtype, *user, *password, *hostname, *login, *helptext;
+static GtkListStore *playerStore;
+static GtkListStore *dbStore;
+static GtkTreeIter selected_iter;
+static int optionsValid;
+static GtkWidget *playerTreeview, *adddb, *deldb, *gameStats, *dbList, *dbtype, *user, *password, *hostname, *login, *helptext;
 
-void CheckDatabase(const char *database);
+static void CheckDatabase(const char *database);
 static void DBListSelected(GtkTreeView * treeview, gpointer userdata);
 
 #define PACK_OFFSET 4
@@ -92,7 +92,7 @@ create_model(void)
     GtkTreeIter iter;
     RowSet *rs;
 
-    long moves[4];
+    int moves[4];
     unsigned int i, j;
     gfloat stats[14];
 
@@ -134,7 +134,7 @@ create_model(void)
 
     for (j = 1; j < rs->rows; ++j) {
         for (i = 1; i < 5; ++i)
-            moves[i - 1] = strtol(rs->data[j][i], NULL, 0);
+            moves[i - 1] = (int) strtol(rs->data[j][i], NULL, 0);
 
         for (i = 5; i < 14; ++i)
             stats[i - 5] = (float) g_strtod(rs->data[j][i], NULL);
@@ -329,8 +329,8 @@ GetRelList(RowSet * pRow)
     GtkCellRenderer *renderer;
     GtkWidget *treeview;
 
-    unsigned int cols = pRow ? pRow->cols : 0;
-    unsigned int rows = pRow ? pRow->rows : 0;
+    unsigned int cols = pRow ? (unsigned int) pRow->cols : 0;
+    unsigned int rows = pRow ? (unsigned int) pRow->rows : 0;
 
     if (!pRow || !rows || !cols)
         return gtk_label_new(_("Search failed or empty."));
@@ -502,7 +502,9 @@ LoginClicked(GtkButton * UNUSED(button), gpointer dbList)
     if (pdb == NULL)
         return;
 
-    tmpUser = pdb->username, tmpPass = pdb->password, tmpHost = pdb->hostname;
+    tmpUser = pdb->username;
+    tmpPass = pdb->password;
+    tmpHost = pdb->hostname;
 
     pdb->username = gtk_entry_get_text(GTK_ENTRY(user));
     pdb->password = gtk_entry_get_text(GTK_ENTRY(password));
@@ -510,7 +512,9 @@ LoginClicked(GtkButton * UNUSED(button), gpointer dbList)
 
     TryConnection(pdb, dbList);
 
-    pdb->username = tmpUser, pdb->password = tmpPass, pdb->hostname = tmpHost;
+    pdb->username = tmpUser;
+    pdb->password = tmpPass;
+    pdb->hostname = tmpHost;
 }
 
 static void
