@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrolls.c,v 1.37 2013/06/16 02:16:16 mdpetch Exp $
+ * $Id: gtkrolls.c,v 1.38 2015/10/24 21:39:04 plm Exp $
  */
 
 #include "config.h"
@@ -24,6 +24,8 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include "lib/simd.h"
+
 #include "gtkgame.h"
 #include "drawboard.h"
 #include "format.h"
@@ -53,7 +55,7 @@ add_level(GtkTreeStore * model, GtkTreeIter * iter,
     GtkTreeIter child_iter;
     cubeinfo ci;
     TanBoard an;
-    float ar[NUM_ROLLOUT_OUTPUTS];
+    SSE_ALIGN(float ar[NUM_ROLLOUT_OUTPUTS]);
     int anMove[8];
     int i;
 
