@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: html.c,v 1.231 2013/06/16 02:16:17 mdpetch Exp $
+ * $Id: html.c,v 1.241 2016/05/07 20:54:41 plm Exp $
  */
 
 #include "config.h"
@@ -40,6 +40,8 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
+#include "glib-ext.h"
+
 #ifdef WIN32
 #include <io.h>
 #endif
@@ -119,12 +121,6 @@ static const char *aaszStyleSheetClasses[NUM_CLASSES][2] = {
     {"boardimage", "vertical-align: top"}
 };
 
-#define FORMATHTMLPROB(f) \
-( ( f ) < 1.0f ) ? "&nbsp;" : "", \
-( ( f ) < 0.1f ) ? "&nbsp;" : "", \
-( f ) * 100.0f
-
-
 const char *aszHTMLExportType[NUM_HTML_EXPORT_TYPES] = {
     "gnu",
     "bbs",
@@ -167,7 +163,7 @@ WriteStyleSheet(FILE * pf, const htmlexportcss hecss)
 
         fputs("\n"
               "/* CSS Stylesheet for " VERSION_STRING " */\n"
-              "/* $Id: html.c,v 1.231 2013/06/16 02:16:17 mdpetch Exp $ */\n", pf);
+              "/* $Id: html.c,v 1.241 2016/05/07 20:54:41 plm Exp $ */\n", pf);
 
     fputs("/* This file is distributed as a part of the "
           "GNU Backgammon program. */\n"
@@ -212,7 +208,7 @@ GetStyle(const stylesheetclass ssc, const htmlexportcss hecss)
 
 
 static char *
-GetStyleGeneral(const htmlexportcss hecss, ...)
+GetStyleGeneral(const int hecss, ...)
 {
 
     static char sz[2048];
@@ -529,7 +525,7 @@ printHTMLBoardBBS(FILE * pf, matchstate * pms, int fTurn,
 
     /* Begin table  and print for player 0 */
     fprintf(pf,
-            "<table style=\"page-break-inside: avoid\"><tr><th align=\"left\">%s</th><th align=\"right\">%d</th></tr>",
+            "<table style=\"page-break-inside: avoid\"><tr><th align=\"left\">%s</th><th align=\"right\">%u</th></tr>",
             ap[0].szName, anPips[1]);
 
     /* avoid page break when printing */
@@ -555,7 +551,7 @@ printHTMLBoardBBS(FILE * pf, matchstate * pms, int fTurn,
 
     /* player 0's chequers on the bar */
 
-    sprintf(sz, "b_up_%d", anBoard[0][24]);
+    sprintf(sz, "b_up_%u", anBoard[0][24]);
     printImageClass(pf, szImageDir, sz, szExtension, NULL, hecss, HTML_EXPORT_TYPE_BBS, CLASS_BOARD_IMG);
 
     /* player 0's outer board */
@@ -583,7 +579,7 @@ printHTMLBoardBBS(FILE * pf, matchstate * pms, int fTurn,
 
         /* dice rolled */
 
-        sprintf(sz, "b_center%d%d%s",
+        sprintf(sz, "b_center%u%u%s",
                 (pms->anDice[0] < pms->anDice[1]) ?
                 pms->anDice[0] : pms->anDice[1],
                 (pms->anDice[0] < pms->anDice[1]) ? pms->anDice[1] : pms->anDice[0], pms->fMove ? "right" : "left");
@@ -620,7 +616,7 @@ printHTMLBoardBBS(FILE * pf, matchstate * pms, int fTurn,
 
     /* player 1's chequers on the bar */
 
-    sprintf(sz, "b_dn_%d", anBoard[1][24]);
+    sprintf(sz, "b_dn_%u", anBoard[1][24]);
     printImageClass(pf, szImageDir, sz, szExtension, NULL, hecss, HTML_EXPORT_TYPE_BBS, CLASS_BOARD_IMG);
 
     /* player 1's outer board */
@@ -646,7 +642,7 @@ printHTMLBoardBBS(FILE * pf, matchstate * pms, int fTurn,
     fputs("</td></tr>\n", pf);
 
     fprintf(pf,
-            "<tr><th align=\"left\">%s</th><th align=\"right\">%d</th><th align=\"center\" colspan=\"2\"></th></tr>",
+            "<tr><th align=\"left\">%s</th><th align=\"right\">%u</th><th align=\"center\" colspan=\"2\"></th></tr>",
             ap[1].szName, anPips[0]);
 
     /* pip counts */
@@ -794,7 +790,7 @@ printHTMLBoardF2H(FILE * pf, matchstate * pms, int fTurn,
 
     if (anBoard[0][24]) {
 
-        sprintf(sz, "b-bar-x%d", (anBoard[0][24] > 4) ? 4 : anBoard[0][24]);
+        sprintf(sz, "b-bar-x%u", (anBoard[0][24] > 4) ? 4 : anBoard[0][24]);
         sprintf(szAlt, "|%1X&nbsp;|", anBoard[0][24]);
         printImage(pf, szImageDir, sz, szExtension, szAlt, hecss, HTML_EXPORT_TYPE_FIBS2HTML);
 
@@ -915,8 +911,8 @@ printHTMLBoardF2H(FILE * pf, matchstate * pms, int fTurn,
 
     if (anBoard[1][24]) {
 
-        sprintf(sz, "b-bar-o%d", (anBoard[1][24] > 4) ? 4 : anBoard[1][24]);
-        sprintf(szAlt, "|&nbsp;%1dO|", anBoard[1][24]);
+        sprintf(sz, "b-bar-o%u", (anBoard[1][24] > 4) ? 4 : anBoard[1][24]);
+        sprintf(szAlt, "|&nbsp;%1uO|", anBoard[1][24]);
         printImage(pf, szImageDir, sz, szExtension, szAlt, hecss, HTML_EXPORT_TYPE_FIBS2HTML);
 
     } else
@@ -956,7 +952,7 @@ printHTMLBoardF2H(FILE * pf, matchstate * pms, int fTurn,
     printImage(pf, szImageDir, "b-indent", szExtension, "", hecss, HTML_EXPORT_TYPE_FIBS2HTML);
 
     PipCount((ConstTanBoard) anBoard, anPips);
-    fprintf(pf, _("Pip counts: %s %d, %s %d<br />\n"), ap[0].szName, anPips[1], ap[1].szName, anPips[0]);
+    fprintf(pf, _("Pip counts: %s %u, %s %u<br />\n"), ap[0].szName, anPips[1], ap[1].szName, anPips[0]);
 
     /* position ID */
 
@@ -1137,7 +1133,7 @@ printHTMLBoardGNU(FILE * pf, matchstate * pms, int fTurn,
     fputs("<tr>", pf);
     fputs("<td>", pf);
 
-    sprintf(sz, "b-bar-o%d", anBoard[1][24]);
+    sprintf(sz, "b-bar-o%u", anBoard[1][24]);
     if (anBoard[1][24])
         sprintf(szAlt,
                 "|&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
@@ -1177,8 +1173,8 @@ printHTMLBoardGNU(FILE * pf, matchstate * pms, int fTurn,
 
         /* player has rolled the dice */
 
-        sprintf(sz, "b-midl-x%d%d", pms->anDice[0], pms->anDice[1]);
-        sprintf(szAlt, "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;%d&nbsp;%d&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;",
+        sprintf(sz, "b-midl-x%u%u", pms->anDice[0], pms->anDice[1]);
+        sprintf(szAlt, "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;%u&nbsp;%u&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;",
                 pms->anDice[0], pms->anDice[1]);
 
         printImage(pf, szImageDir, sz, szExtension, szAlt, hecss, HTML_EXPORT_TYPE_GNU);
@@ -1226,8 +1222,8 @@ printHTMLBoardGNU(FILE * pf, matchstate * pms, int fTurn,
 
         /* player 1 has rolled the dice */
 
-        sprintf(sz, "b-midr-o%d%d", pms->anDice[0], pms->anDice[1]);
-        sprintf(szAlt, "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;%d&nbsp;%d&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;",
+        sprintf(sz, "b-midr-o%u%u", pms->anDice[0], pms->anDice[1]);
+        sprintf(szAlt, "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;%u&nbsp;%u&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;",
                 pms->anDice[0], pms->anDice[1]);
 
         printImage(pf, szImageDir, sz, szExtension, szAlt, hecss, HTML_EXPORT_TYPE_GNU);
@@ -1295,7 +1291,7 @@ printHTMLBoardGNU(FILE * pf, matchstate * pms, int fTurn,
 
     fputs("<td>", pf);
 
-    sprintf(sz, "b-bar-x%d", anBoard[0][24]);
+    sprintf(sz, "b-bar-x%u", anBoard[0][24]);
     if (pms->fCubeOwner == 1)
         sprintf(szAlt, "|%2d&nbsp;|", pms->nCube);
     else
@@ -1378,7 +1374,7 @@ printHTMLBoardGNU(FILE * pf, matchstate * pms, int fTurn,
     fputs("<p>", pf);
 
     PipCount((ConstTanBoard) anBoard, anPips);
-    fprintf(pf, _("Pip counts: %s %d, %s %d<br />\n"), ap[0].szName, anPips[1], ap[1].szName, anPips[0]);
+    fprintf(pf, _("Pip counts: %s %u, %s %u<br />\n"), ap[0].szName, anPips[1], ap[1].szName, anPips[0]);
 
     /* position ID */
 
@@ -1463,7 +1459,7 @@ HTMLBoardHeader(FILE * pf, const matchstate * pms,
 
         /* chequer play decision */
 
-        fprintf(pf, _(" %s to play %d%d"), ap[pms->fMove].szName, pms->anDice[0], pms->anDice[1]
+        fprintf(pf, _(" %s to play %u%u"), ap[pms->fMove].szName, pms->anDice[0], pms->anDice[1]
             );
 
     else if (pms->fDoubled)
@@ -1584,7 +1580,7 @@ HTMLEpilogue(FILE * pf, const matchstate * UNUSED(pms), char *aszLinks[4], const
     int fFirst;
     int i;
 
-    const char szVersion[] = "$Revision: 1.231 $";
+    const char szVersion[] = "$Revision: 1.241 $";
     int iMajor, iMinor;
 
     iMajor = atoi(strchr(szVersion, ' '));
@@ -1625,14 +1621,14 @@ HTMLEpilogue(FILE * pf, const matchstate * UNUSED(pms), char *aszLinks[4], const
     fprintf(pf,
             "</address>\n"
             "<p>\n"
-            "<a href=\"http://validator.w3.org/check/referer\">"
-            "<img style=\"border: 0\" width=\"88\" height=\"31\" "
+            "<a href=\"http://validator.w3.org/check?uri=referer\">"
+            "<img style=\"border:0;width:88px;height:31px\" "
             "src=\"http://www.w3.org/Icons/valid-xhtml10\" "
             "alt=\"%s\" /></a>\n"
             "<a href=\"http://jigsaw.w3.org/css-validator/check/referer\">"
-            "<img style=\"border: 0\" width=\"88\" height=\"31\" "
+            "<img style=\"border:0;width=88px;height:31px\" "
             "src=\"http://jigsaw.w3.org/css-validator/images/vcss\" "
-            "alt=\"%s\" />" "</a>\n" "</p>\n" "</body>\n" "</html>\n", _("Valid XHTML 1.0!"), _("Valid CSS!"));
+            "alt=\"%s\" />" "</a>\n" "</p>\n" "</body>\n" "</html>\n", _("Valid XHTML 1.0 Strict!"), _("Valid CSS!"));
 
 
 }
@@ -1654,7 +1650,7 @@ HTMLEpilogueComment(FILE * pf)
 
     time_t t;
 
-    const char szVersion[] = "$Revision: 1.231 $";
+    const char szVersion[] = "$Revision: 1.241 $";
     int iMajor, iMinor;
     char *pc;
 
@@ -1881,7 +1877,7 @@ HTMLPrintCubeAnalysisTable(FILE * pf,
                 "</span> %s</td>"
                 "<td %s>%s</td>"
                 "<td %s>(%s: <span %s>%s</span>)</td>\n",
-                (!pci->nMatchTo || (pci->nMatchTo && !fOutputMWC)) ?
+                (!pci->nMatchTo || !fOutputMWC) ?
                 _("cubeless equity") : _("cubeless MWC"),
                 GetStyle(CLASS_CUBE_EQUITY, hecss),
                 OutputEquity(aarOutput[0][OUTPUT_EQUITY], pci, TRUE),
@@ -2136,7 +2132,7 @@ HTMLPrintMoveAnalysis(FILE * pf, matchstate * pms, moverecord * pmr,
         fprintf(pf, "<p><span %s>", GetStyle(CLASS_BLUNDER, hecss));
         fprintf(pf, _("Alert: %s move"), gettext(aszSkillType[pmr->n.stMove]));
 
-        if (!pms->nMatchTo || (pms->nMatchTo && !fOutputMWC))
+        if (!pms->nMatchTo || !fOutputMWC)
             fprintf(pf, " (%+7.3f)</span></p>\n", pmr->ml.amMoves[pmr->n.iMove].rScore - pmr->ml.amMoves[0].rScore);
         else
             fprintf(pf, " (%+6.3f%%)</span></p>\n",
@@ -2153,7 +2149,7 @@ HTMLPrintMoveAnalysis(FILE * pf, matchstate * pms, moverecord * pmr,
         fprintf(pf, "<p><span %s>", GetStyle(CLASS_JOKER, hecss));
         fprintf(pf, _("Alert: %s roll!"), gettext(aszLuckType[pmr->lt]));
 
-        if (!pms->nMatchTo || (pms->nMatchTo && !fOutputMWC))
+        if (!pms->nMatchTo || !fOutputMWC)
             fprintf(pf, " (%+7.3f)</span></p>\n", pmr->rLuck);
         else
             fprintf(pf, " (%+6.3f%%)</span></p>\n", 100.0f * eq2mwc(pmr->rLuck, &ci) - 100.0f * eq2mwc(0.0f, &ci));
@@ -2172,7 +2168,7 @@ HTMLPrintMoveAnalysis(FILE * pf, matchstate * pms, moverecord * pmr,
     fprintf(pf,
             "<th %s>%s</th>\n" "</tr>\n",
             GetStyleGeneral(hecss, CLASS_MOVEHEADER, CLASS_MOVEEQUITY, -1),
-            (!pms->nMatchTo || (pms->nMatchTo && !fOutputMWC)) ? _("Equity") : _("MWC"));
+            (!pms->nMatchTo || !fOutputMWC) ? _("Equity") : _("MWC"));
 
 
     if (pmr->ml.cMoves) {
@@ -2196,7 +2192,7 @@ HTMLPrintMoveAnalysis(FILE * pf, matchstate * pms, moverecord * pmr,
             /* move no */
 
             if (i != pmr->n.iMove || i != pmr->ml.cMoves - 1 || pmr->ml.cMoves == 1 || i < exsExport.nMoves)
-                fprintf(pf, "<td %s>%d</td>\n", GetStyle(CLASS_MOVENUMBER, hecss), i + 1);
+                fprintf(pf, "<td %s>%u</td>\n", GetStyle(CLASS_MOVENUMBER, hecss), i + 1);
             else
                 fprintf(pf, "<td %s>\?\?</td>\n", GetStyle(CLASS_MOVENUMBER, hecss));
 
@@ -2207,7 +2203,7 @@ HTMLPrintMoveAnalysis(FILE * pf, matchstate * pms, moverecord * pmr,
                 fprintf(pf, "<td %s>n/a</td>\n", GetStyle(CLASS_MOVEPLY, hecss));
                 break;
             case EVAL_EVAL:
-                fprintf(pf, "<td %s>%d</td>\n", GetStyle(CLASS_MOVEPLY, hecss), pmr->ml.amMoves[i].esMove.ec.nPlies);
+                fprintf(pf, "<td %s>%u</td>\n", GetStyle(CLASS_MOVEPLY, hecss), pmr->ml.amMoves[i].esMove.ec.nPlies);
                 break;
             case EVAL_ROLLOUT:
                 fprintf(pf, "<td %s>R</td>\n", GetStyle(CLASS_MOVEPLY, hecss));
@@ -2593,7 +2589,7 @@ HTMLPrintComment(FILE * pf, const moverecord * pmr, const htmlexportcss hecss)
 
         fputs("<!-- Annotation -->\n\n", pf);
 
-        fprintf(pf, "<br />\n" "<div %s>", GetStyle(CLASS_COMMENTHEADER, hecss));
+        fprintf(pf, "<p></p>\n" "<div %s>", GetStyle(CLASS_COMMENTHEADER, hecss));
         fputs(_("Annotation"), pf);
         fputs("</div>\n", pf);
 
@@ -2877,7 +2873,7 @@ OpenCSS(const char *sz)
     if (g_file_test(pchCSS, G_FILE_TEST_EXISTS)) {
         outputf(_("gnubg.css is not written since it already exist in \"%s\"\n"), pchBase);
         pf = NULL;
-    } else if (!(pf = g_fopen(pchCSS, "w"))) {
+    } else if (!(pf = gnubg_g_fopen(pchCSS, "w"))) {
         outputerr(pchCSS);
     }
 
@@ -2934,7 +2930,7 @@ CommandExportGameHtml(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -3025,7 +3021,7 @@ CommandExportMatchHtml(char *sz)
 
         if (!strcmp(szCurrent, "-"))
             pf = stdout;
-        else if (!(pf = g_fopen(szCurrent, "w"))) {
+        else if (!(pf = gnubg_g_fopen(szCurrent, "w"))) {
             outputerr(szCurrent);
             for (j = 0; j < 4; j++)
                 g_free(filenames[j]);
@@ -3084,7 +3080,7 @@ CommandExportPositionHtml(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -3140,7 +3136,6 @@ static void
 ExportPositionGammOnLine(FILE * pf)
 {
     int fHistory;
-    int iMove;
     moverecord *pmr = get_current_moverecord(&fHistory);
 
     if (!pmr) {
@@ -3152,37 +3147,22 @@ ExportPositionGammOnLine(FILE * pf)
 
     fputs("<strong>", pf);
 
-    fprintf(pf,
-            ngettext("The score (after %d game) is: %s %d, %s %d",
-                     "The score (after %d games) is: %s %d, %s %d",
-                     ms.cGames), ms.cGames, ap[0].szName, ms.anScore[0], ap[1].szName, ms.anScore[1]);
-
-    if (ms.nMatchTo > 0)
+    if (ms.nMatchTo > 1)
         fprintf(pf,
-                ngettext(" (match to %d point%s)",
-                         " (match to %d points%s)",
-                         ms.nMatchTo),
-                ms.nMatchTo, ms.fCrawford ? _(", Crawford game") : (ms.fPostCrawford ? _(", post-Crawford play") : ""));
+                gettext("Match to %d points - %s %d, %s %d%s"),
+                ms.nMatchTo,
+                ap[0].szName, ms.anScore[0], ap[1].szName, ms.anScore[1],
+                ms.fCrawford ? _(", Crawford game") : (ms.fPostCrawford ? _(", post-Crawford play") : ""));
+    else if (ms.nMatchTo == 1)
+        fprintf(pf, _("Match to 1 point"));
+    else
+        fprintf(pf, gettext("Unlimited game, %s"), ms.fJacoby ? _("Jacoby rule") : _("without Jacoby rule"));
+
     fputs("</strong>\n", pf);
 
     fputs("\n<!-- End Score -->\n\n", pf);
 
-
-    if (fHistory)
-        iMove = getMoveNumber(plGame, pmr) - 1;
-    else if (plLastMove)
-        iMove = getMoveNumber(plGame, plLastMove->p);
-    else
-        iMove = -1;
-    HTMLBoardHeader(pf, &ms, HTML_EXPORT_TYPE_BBS, HTML_EXPORT_CSS_INLINE, getGameNumber(plGame), iMove, FALSE);
-
-    printHTMLBoard(pf, &ms, ms.fTurn,
-#ifdef GAMMONLINE_TEST
-                   "http://www.gammonline.com/demo/Images/",
-#else
-                   "../Images/",
-#endif
-                   "gif", HTML_EXPORT_TYPE_BBS, HTML_EXPORT_CSS_INLINE);
+    printHTMLBoard(pf, &ms, ms.fTurn, "../Images/", "gif", HTML_EXPORT_TYPE_BBS, HTML_EXPORT_CSS_INLINE);
 
     if (pmr) {
         HTMLAnalysis(pf, &ms, pmr, "../Images/", "gif", HTML_EXPORT_TYPE_BBS, HTML_EXPORT_CSS_INLINE);
@@ -3219,7 +3199,7 @@ CommandExportPositionGammOnLine(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
