@@ -2,11 +2,16 @@
  * ------------------------------------------------------------------------------
  * Standard definitions and types, Bob Jenkins
  * Modified for inclusion with GNU Backgammon by Gary Wong
- * $Id: isaacs.h,v 1.4 2013/06/16 02:16:24 mdpetch Exp $
+ * $Id: isaacs.h,v 1.5 2013/09/09 21:06:21 plm Exp $
  * ------------------------------------------------------------------------------
  */
 #ifndef ISAACS_H
 #define ISAACS_H
+
+#if 0
+
+/* Pre-64bits relics. Most of them are not used anyway */
+
 typedef unsigned long int ub4;  /* unsigned 4-byte quantities */
 #define UB4MAXVAL 0xffffffff
 typedef signed long int sb4;
@@ -19,6 +24,18 @@ typedef unsigned char ub1;
 #define UB1MAXVAL 0xff
 typedef signed char sb1;        /* signed 1-byte quantities */
 #define SB1MAXVAL 0x7f
+
+#endif
+
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#else
+typedef unsigned int uint32_t;
+#endif
+
+typedef uint32_t ub4;           /* unsigned 4-byte quantities */
+#define UB4MAXVAL 0xffffffff
+
 typedef int word;               /* fastest type available */
 
 #endif
