@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: makehyper.c,v 1.47 2015/04/12 22:13:49 plm Exp $
+ * $Id: makehyper.c,v 1.49 2015/10/14 21:29:40 plm Exp $
  */
 
 #include "config.h"
@@ -70,8 +70,6 @@ MT_CloseThreads(void)
     return;
 }
 
-static int aiNorm[10];
-
 static hyperclass
 ClassifyHyper(TanBoard anBoard)
 {
@@ -206,7 +204,7 @@ StartFromDatabase(hyperequity ahe[], const int nC, const char *szFilename)
     int i, j, k;
     float r;
 
-    if (!(pf = g_fopen(szFilename, "r+b"))) {
+    if (!(pf = gnubg_g_fopen(szFilename, "r+b"))) {
         perror(szFilename);
         exit(2);
     }
@@ -450,14 +448,12 @@ HyperEquity(const int nUs, const int nThem, hyperequity * phe, const int nC, con
         r = fabsf(phe->arOutput[k] - heOld.arOutput[k]);
         if (r > arNorm[k]) {
             arNorm[k] = r;
-            aiNorm[k] = nUs * nPos + nThem;
         }
     }
     for (k = 0; k < 5; ++k) {
         r = fabsf(phe->arEquity[k] - heOld.arEquity[k]);
         if (r > arNorm[5 + k]) {
             arNorm[5 + k] = r;
-            aiNorm[5 + k] = nUs * nPos + nThem;
         }
     }
 
@@ -531,7 +527,7 @@ WriteHyperFile(const char *szFilename, const hyperequity ahe[], const int nC)
     FILE *pf;
 
 
-    if (!(pf = g_fopen(szFilename, "w+b"))) {
+    if (!(pf = gnubg_g_fopen(szFilename, "w+b"))) {
         perror(szFilename);
         return;
     }
@@ -596,7 +592,7 @@ main(int argc, char **argv)
          "Print version info and exit", NULL},
         {"outfile", 'f', 0, G_OPTION_ARG_STRING, &szOutput,
          "Output filename. Default is hyper<C>.bd.", "filename"},
-        {NULL, 0, 0, 0, NULL, NULL, NULL}
+        {NULL, 0, 0, (GOptionArg) 0, NULL, NULL, NULL}
     };
 
     GError *error = NULL;
@@ -688,10 +684,6 @@ main(int argc, char **argv)
 
         CalcNewEquity(aheEquity, nC, arNorm);
 
-        /*
-         * for ( i = 0; i < 10; ++i ) 
-         * printf( "Norm[%d]=%f (%d)\n", i, arNorm[ i ], aiNorm[ i ] ); */
-
         rNorm = NormOO(arNorm, 10);
 
         printf(_("norm of delta: %f\n"), rNorm);
