@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: matchequity.c,v 1.92 2013/06/16 02:16:18 mdpetch Exp $
+ * $Id: matchequity.c,v 1.98 2016/05/11 21:33:08 plm Exp $
  */
 
 #include "config.h"
@@ -36,10 +36,6 @@
 #include "mec.h"
 #include "util.h"
 
-#define DELTA         0.08
-#define DELTABAR      0.06
-#define G1            0.25
-#define G2            0.15
 #define GAMMONRATE    0.25
 
 #include "eval.h"
@@ -123,8 +119,8 @@ NormalDistArea(float rMin, float rMax, float rMu, float rSigma)
     rtMin = (rMin - rMu) / rSigma;
     rtMax = (rMax - rMu) / rSigma;
 
-    rInt1 = (erf(rtMin / sqrtf(2)) + 1.0f) / 2.0f;
-    rInt2 = (erf(rtMax / sqrtf(2)) + 1.0f) / 2.0f;
+    rInt1 = (erff(rtMin / sqrtf(2)) + 1.0f) / 2.0f;
+    rInt2 = (erff(rtMax / sqrtf(2)) + 1.0f) / 2.0f;
 
     return rInt2 - rInt1;
 }
@@ -251,7 +247,7 @@ initMETZadeh(float aafMET[MAXSCORE][MAXSCORE],
     for (i = 0; i < MAXSCORE; i++) {
 
         aafMET[i][0] = rG1 * 0.5f * ((i - 2 >= 0) ? afMETPostCrawford[i - 2] : 1.0f)
-            + (1.0 - rG1) * 0.5f * ((i - 1 >= 0) ? afMETPostCrawford[i - 1] : 1.0f);
+            + (1.0f - rG1) * 0.5f * ((i - 1 >= 0) ? afMETPostCrawford[i - 1] : 1.0f);
         aafMET[0][i] = 1.0f - aafMET[i][0];
 
     }
@@ -272,7 +268,7 @@ initMETZadeh(float aafMET[MAXSCORE][MAXSCORE],
 
                 aaafD1bar[i][j][nCube] = (GET_MET(i - nCubeValue, j, aafMET)
                                           - rG2 * GET_MET(i, j - 4 * nCubePrimeValue, aafMET)
-                                          - (1.0 - rG2) * GET_MET(i, j - 2 * nCubePrimeValue, aafMET))
+                                          - (1.0f - rG2) * GET_MET(i, j - 2 * nCubePrimeValue, aafMET))
                     / (rG1 * GET_MET(i - 4 * nCubePrimeValue, j, aafMET)
                        + (1.0f - rG1) * GET_MET(i - 2 * nCubePrimeValue, j, aafMET)
                        - rG2 * GET_MET(i, j - 4 * nCubePrimeValue, aafMET)
@@ -402,7 +398,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
      *
      * Output:
      * - arCP : cash points with live cube
-     * These points are necesary for the linear
+     * These points are necessary for the linear
      * interpolation used in cubeless -> cubeful equity 
      * transformation.
      */
@@ -434,7 +430,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
 
         /* arOutput evaluated for player 0 */
 
-        if (arOutput[OUTPUT_WIN] > 0.0) {
+        if (arOutput[OUTPUT_WIN] > 0.0f) {
             arG[0] = (arOutput[OUTPUT_WINGAMMON] - arOutput[OUTPUT_WINBACKGAMMON]) / arOutput[OUTPUT_WIN];
             arBG[0] = arOutput[OUTPUT_WINBACKGAMMON] / arOutput[OUTPUT_WIN];
         } else {
@@ -442,7 +438,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
             arBG[0] = 0.0;
         }
 
-        if (arOutput[OUTPUT_WIN] < 1.0) {
+        if (arOutput[OUTPUT_WIN] < 1.0f) {
             arG[1] = (arOutput[OUTPUT_LOSEGAMMON] - arOutput[OUTPUT_LOSEBACKGAMMON]) / (1.0f - arOutput[OUTPUT_WIN]);
             arBG[1] = arOutput[OUTPUT_LOSEBACKGAMMON] / (1.0f - arOutput[OUTPUT_WIN]);
         } else {
@@ -454,7 +450,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
 
         /* arOutput evaluated for player 1 */
 
-        if (arOutput[OUTPUT_WIN] > 0.0) {
+        if (arOutput[OUTPUT_WIN] > 0.0f) {
             arG[1] = (arOutput[OUTPUT_WINGAMMON] - arOutput[OUTPUT_WINBACKGAMMON]) / arOutput[OUTPUT_WIN];
             arBG[1] = arOutput[OUTPUT_WINBACKGAMMON] / arOutput[OUTPUT_WIN];
         } else {
@@ -462,7 +458,7 @@ GetPoints(float arOutput[5], const cubeinfo * pci, float arCP[2])
             arBG[1] = 0.0;
         }
 
-        if (arOutput[OUTPUT_WIN] < 1.0) {
+        if (arOutput[OUTPUT_WIN] < 1.0f) {
             arG[0] = (arOutput[OUTPUT_LOSEGAMMON] - arOutput[OUTPUT_LOSEBACKGAMMON]) / (1.0f - arOutput[OUTPUT_WIN]);
             arBG[0] = arOutput[OUTPUT_LOSEBACKGAMMON] / (1.0f - arOutput[OUTPUT_WIN]);
         } else {
@@ -583,12 +579,12 @@ GetDoublePointDeadCube(float arOutput[5], cubeinfo * pci)
 
         float rW, rL;
 
-        if (arOutput[0] > 0.0)
+        if (arOutput[0] > 0.0f)
             rW = 1.0f + (arOutput[1] + arOutput[2]) / arOutput[0];
         else
             rW = 1.0f;
 
-        if (arOutput[0] < 1.0)
+        if (arOutput[0] < 1.0f)
             rL = 1.0f + (arOutput[3] + arOutput[4]) / (1.0f - arOutput[0]);
         else
             rL = 1.0f;
@@ -621,7 +617,7 @@ GetDoublePointDeadCube(float arOutput[5], cubeinfo * pci)
         float rRisk, rGain;
 
         /* FIXME: avoid division by zero */
-        if (arOutput[OUTPUT_WIN] > 0.0) {
+        if (arOutput[OUTPUT_WIN] > 0.0f) {
             rG1 = (arOutput[OUTPUT_WINGAMMON] - arOutput[OUTPUT_WINBACKGAMMON]) / arOutput[OUTPUT_WIN];
             rBG1 = arOutput[OUTPUT_WINBACKGAMMON] / arOutput[OUTPUT_WIN];
         } else {
@@ -629,7 +625,7 @@ GetDoublePointDeadCube(float arOutput[5], cubeinfo * pci)
             rBG1 = 0.0;
         }
 
-        if (arOutput[OUTPUT_WIN] < 1.0) {
+        if (arOutput[OUTPUT_WIN] < 1.0f) {
             rG2 = (arOutput[OUTPUT_LOSEGAMMON] - arOutput[OUTPUT_LOSEBACKGAMMON]) / (1.0f - arOutput[OUTPUT_WIN]);
             rBG2 = arOutput[OUTPUT_LOSEBACKGAMMON] / (1.0f - arOutput[OUTPUT_WIN]);
         } else {
@@ -711,7 +707,7 @@ ExtendMET(float aarMET[MAXSCORE][MAXSCORE], const int nMaxScore)
 
             nScore1 = j + 1;
 
-            rGames = (nScore0 + nScore1) / 2.00f;
+            rGames = (nScore0 + nScore1) / 2.0f;
 
             if (nScore1 > 10)
                 rStddev1 = 1.77f;
@@ -1092,7 +1088,7 @@ readMET(metdata * met, const char *filename)
     parser->i = 0;
     parser->j = 0;
 
-    if (!(context = g_markup_parse_context_new(&markup_parser, 0, parser, met_parser_destroy))) {
+    if (!(context = g_markup_parse_context_new(&markup_parser, (GMarkupParseFlags) 0, parser, met_parser_destroy))) {
         g_warning("Can't create XML parser\n");
         g_free(parser);
         return -1;
@@ -1384,7 +1380,7 @@ static void
 met_parser_error(GMarkupParseContext * UNUSED(context), GError * UNUSED(error), gpointer user_data)
 {
     MatchEquityParser *parser = (MatchEquityParser *) user_data;
-    g_warning("An error occured while parsing file: %s\n", parser->filename);
+    g_warning("An error occurred while parsing file: %s\n", parser->filename);
 }
 
 /*
@@ -1445,7 +1441,7 @@ getGammonPrice(float arGammonPrice[4],
 
     /* avoid division by zero */
 
-    if (fabs(rWin - rCenter) > epsilon) {
+    if (fabsf(rWin - rCenter) > epsilon) {
 
         /* this expression can be reduced to: 
          * 2 * ( rWinGammon - rWin ) / ( rWin - rLose )
@@ -1463,23 +1459,18 @@ getGammonPrice(float arGammonPrice[4],
         arGammonPrice[3] = (rCenter - rLoseBG) / (rWin - rCenter) - (arGammonPrice[1] + 1.0f);
 
     } else
-        arGammonPrice[0] = arGammonPrice[1] = arGammonPrice[2] = arGammonPrice[3] = 0.0;
+        arGammonPrice[0] = arGammonPrice[1] = arGammonPrice[2] = arGammonPrice[3] = 0.0f;
 
 
     /* Correct numerical problems */
-    if (arGammonPrice[0] <= 0)
-        arGammonPrice[0] = 0.0;
-    if (arGammonPrice[1] <= 0)
-        arGammonPrice[1] = 0.0;
-    if (arGammonPrice[2] <= 0)
-        arGammonPrice[2] = 0.0;
-    if (arGammonPrice[3] <= 0)
-        arGammonPrice[3] = 0.0;
-
-    g_assert(arGammonPrice[0] >= 0);
-    g_assert(arGammonPrice[1] >= 0);
-    g_assert(arGammonPrice[2] >= 0);
-    g_assert(arGammonPrice[3] >= 0);
+    if (arGammonPrice[0] < 0.0f)
+        arGammonPrice[0] = 0.0f;
+    if (arGammonPrice[1] < 0.0f)
+        arGammonPrice[1] = 0.0f;
+    if (arGammonPrice[2] < 0.0f)
+        arGammonPrice[2] = 0.0f;
+    if (arGammonPrice[3] < 0.0f)
+        arGammonPrice[3] = 0.0f;
 
 }
 
@@ -1632,10 +1623,10 @@ getME(const int nScore0, const int nScore1, const int nMatchTo,
 
     /* check if any player has won the match */
 
-    if (n0 < 0)
+    if (unlikely(n0 < 0))
         /* player 0 has won the game */
         return (fPlayer) ? 0.0f : 1.0f;
-    else if (n1 < 0)
+    else if (unlikely(n1 < 0))
         /* player 1 has won the game */
         return (fPlayer) ? 1.0f : 0.0f;
 
@@ -1657,9 +1648,6 @@ getME(const int nScore0, const int nScore1, const int nMatchTo,
         /* non-post-Crawford games */
         return (fPlayer) ? 1.0f - aafMET[n0][n1] : aafMET[n0][n1];
 
-    g_assert_not_reached();
-    return 0.0f;
-
 }
 
 
@@ -1699,9 +1687,6 @@ getMEAtScore(const int nScore0, const int nScore1, const int nMatchTo,
         /* non-post-Crawford games */
         return (fPlayer) ? 1.0f - aafMET[n0][n1] : aafMET[n0][n1];
 
-    g_assert_not_reached();
-    return 0.0f;
-
 }
 
 
@@ -1826,14 +1811,14 @@ getMEMultiple(const int nScore0, const int nScore1, const int nMatchTo,
         s0 = *score0++;
         s1 = *score1++;
 
-        if (s0 < 0) {
+        if (unlikely(s0 < 0)) {
             /* player 0 wins */
             *p0++ = 1.0f;
             *p1++ = 0.0f;
-        } else if (s1 < 0) {
+        } else if (unlikely(s1 < 0)) {
             *p0++ = 0.0f;
             *p1++ = 1.0f;
-        } else if (fCrawf) {
+        } else if (unlikely(fCrawf)) {
             if (s0 == 0) {      /* player 0 is leading */
                 *p0++ = 1.0f - aafMETPostCrawford[1][s1];
                 *p1++ = aafMETPostCrawford[1][s1];
