@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: openurl.c,v 1.28 2013/07/22 23:04:00 mdpetch Exp $
+ * $Id: openurl.c,v 1.29 2015/08/31 05:36:26 mdpetch Exp $
  */
 #include "config.h"
 #include <stdio.h>
@@ -25,8 +25,8 @@
 #include "backgammon.h"
 #include "openurl.h"
 #ifdef WIN32
-#include "windows.h"
-#include "shellapi.h"
+#include <windows.h>
+#include <shellapi.h>
 #else
 #include <string.h>
 #endif                          /* WIN32 */
