@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: rollout.c,v 1.246 2015/03/01 13:14:20 plm Exp $
+ * $Id: rollout.c,v 1.249 2015/11/02 20:29:23 plm Exp $
  */
 
 #include "config.h"
@@ -30,9 +30,10 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <time.h>
+#include "glib-ext.h"
 
 #include "backgammon.h"
-#if USE_GTK
+#if defined(USE_GTK)
 #include "gtkgame.h"
 #endif
 #include "matchid.h"
@@ -40,8 +41,9 @@
 #include "format.h"
 #include "multithread.h"
 #include "rollout.h"
+#include "lib/simd.h"
 
-#if !LOCKING_VERSION
+#if !defined(LOCKING_VERSION)
 
 f_BasicCubefulRollout BasicCubefulRollout = BasicCubefulRolloutNoLocking;
 #define BasicCubefulRollout BasicCubefulRolloutNoLocking
@@ -140,7 +142,7 @@ log_game_start(const char *name, const cubeinfo * pci, int fCubeful, TanBoard an
         }
     }
 
-    if ((logfp = g_fopen(name, "w")) == 0)
+    if ((logfp = gnubg_g_fopen(name, "w")) == 0)
         return NULL;
 
     fprintf(logfp, "(;FF[4]GM[6]CA[UTF-8]AP[GNU Backgammon:%s]MI"
@@ -287,7 +289,9 @@ static volatile unsigned int initial_game_count;
 
 #endif
 
-extern void initRolloutstat(rolloutstat * prs);
+#if !defined(LOCKING_VERSION)
+static void initRolloutstat(rolloutstat * prs);
+#endif
 
 /* called with 
  * cube decision                  move rollout
@@ -360,7 +364,12 @@ BasicCubefulRollout(unsigned int aanBoard[][2][25],
     float arMean[NUM_ROLLOUT_OUTPUTS];
     unsigned int aaanBoard[6][6][2][25];
     int aanMoves[6][6][8];
+#if defined(USE_SIMD_INSTRUCTIONS)
+#define NUM_ROLLOUT_OUTPUTS_PADDED (NUM_ROLLOUT_OUTPUTS + VEC_SIZE - (NUM_ROLLOUT_OUTPUTS % VEC_SIZE))
+    SSE_ALIGN(float aaar[6][6][NUM_ROLLOUT_OUTPUTS_PADDED]);
+#else
     float aaar[6][6][NUM_ROLLOUT_OUTPUTS];
+#endif
 
     evalcontext ecCubeless0ply = { FALSE, 0, FALSE, TRUE, 0.0 };
     evalcontext ecCubeful0ply = { TRUE, 0, FALSE, TRUE, 0.0 };
@@ -825,7 +834,7 @@ BasicCubefulRollout(unsigned int aanBoard[][2][25],
     return 0;
 }
 
-#if !LOCKING_VERSION
+#if !defined(LOCKING_VERSION)
 
 /* called with a collection of moves or a cube decision to be rolled out.
  * when called with a cube decision, the number of alternatives is always 2
@@ -1220,7 +1229,7 @@ RolloutLoopMT(void *UNUSED(unused))
         /* Stop rolling out moves whose Equity is more than a user selected multiple of the joint standard
          * deviation of the equity difference with the best move in the list. */
 
-#if !USE_MULTITHREAD
+#if !defined(USE_MULTITHREAD)
         ProcessEvents();
 #endif
 
@@ -1466,8 +1475,8 @@ RolloutGeneral(ConstTanBoard * apBoard,
         multi_debug("rollout finished waiting for tasks to complete");
     }
 
-    /* Make sure final output is upto date */
-#if USE_GTK
+    /* Make sure final output is up to date */
+#if defined(USE_GTK)
     if (!fX)
 #endif
         if (!fInterrupt)
@@ -1505,7 +1514,7 @@ RolloutGeneral(ConstTanBoard * apBoard,
     }
 
     if (fShowProgress && !fInterrupt
-#if USE_GTK
+#if defined(USE_GTK)
         && !fX
 #endif
         ) {
@@ -1708,7 +1717,7 @@ GeneralCubeDecisionR(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
  *
  */
 
-extern void
+static void
 initRolloutstat(rolloutstat * prs)
 {
 
@@ -1836,7 +1845,6 @@ ScoreMoveRollout(move ** ppm, cubeinfo ** ppci, int cMoves, rolloutprogressfunc
 
         /* swap fMove in cubeinfo */
         aci[i].fMove = !aci[i].fMove;
-
     }
 
     nGamesDone = RolloutGeneral(apBoard,
