@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: sgf.c,v 1.155 2015/02/01 18:11:53 plm Exp $
+ * $Id: sgf.c,v 1.159 2016/01/31 13:34:29 plm Exp $
  */
 
 #include "config.h"
@@ -29,6 +29,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "glib-ext.h"
 
 #include "backgammon.h"
 #include "dice.h"
@@ -107,7 +108,7 @@ LoadCollection(char *sz)
     SGFErrorHandler = ErrorHandler;
 
     if (strcmp(sz, "-")) {
-        if (!(pf = g_fopen(sz, "r"))) {
+        if (!(pf = gnubg_g_fopen(sz, "r"))) {
             outputerr(sz);
             return NULL;
         }
@@ -220,72 +221,72 @@ RestoreGS(listOLD * pl, statcontext * psc)
         case 'M':              /* moves */
             psc->fMoves = TRUE;
 
-            psc->anUnforcedMoves[0] = (int)strtol(pch + 2, &pch, 10);
-            psc->anUnforcedMoves[1] = (int)strtol(pch, &pch, 10);
-            psc->anTotalMoves[0] = (int)strtol(pch, &pch, 10);
-            psc->anTotalMoves[1] = (int)strtol(pch, &pch, 10);
+            psc->anUnforcedMoves[0] = (int) strtol(pch + 2, &pch, 10);
+            psc->anUnforcedMoves[1] = (int) strtol(pch, &pch, 10);
+            psc->anTotalMoves[0] = (int) strtol(pch, &pch, 10);
+            psc->anTotalMoves[1] = (int) strtol(pch, &pch, 10);
 
             for (st = SKILL_VERYBAD; st <= SKILL_NONE; st++) {
-                psc->anMoves[0][st] = (int)strtol(pch, &pch, 10);
-                psc->anMoves[1][st] = (int)strtol(pch, &pch, 10);
+                psc->anMoves[0][st] = (int) strtol(pch, &pch, 10);
+                psc->anMoves[1][st] = (int) strtol(pch, &pch, 10);
             }
 
-            psc->arErrorCheckerplay[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorCheckerplay[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorCheckerplay[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorCheckerplay[1][1] = (float)g_ascii_strtod(pch, &pch);
+            psc->arErrorCheckerplay[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorCheckerplay[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorCheckerplay[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorCheckerplay[1][1] = (float) g_ascii_strtod(pch, &pch);
 
             break;
 
         case 'C':              /* cube */
             psc->fCube = TRUE;
 
-            psc->anTotalCube[0] = (int)strtol(pch + 2, &pch, 10);
-            psc->anTotalCube[1] = (int)strtol(pch, &pch, 10);
-            psc->anDouble[0] = (int)strtol(pch, &pch, 10);
-            psc->anDouble[1] = (int)strtol(pch, &pch, 10);
-            psc->anTake[0] = (int)strtol(pch, &pch, 10);
-            psc->anTake[1] = (int)strtol(pch, &pch, 10);
-            psc->anPass[0] = (int)strtol(pch, &pch, 10);
-            psc->anPass[1] = (int)strtol(pch, &pch, 10);
+            psc->anTotalCube[0] = (int) strtol(pch + 2, &pch, 10);
+            psc->anTotalCube[1] = (int) strtol(pch, &pch, 10);
+            psc->anDouble[0] = (int) strtol(pch, &pch, 10);
+            psc->anDouble[1] = (int) strtol(pch, &pch, 10);
+            psc->anTake[0] = (int) strtol(pch, &pch, 10);
+            psc->anTake[1] = (int) strtol(pch, &pch, 10);
+            psc->anPass[0] = (int) strtol(pch, &pch, 10);
+            psc->anPass[1] = (int) strtol(pch, &pch, 10);
 
-            psc->anCubeMissedDoubleDP[0] = (int)strtol(pch, &pch, 10);
-            psc->anCubeMissedDoubleDP[1] = (int)strtol(pch, &pch, 10);
-            psc->anCubeMissedDoubleTG[0] = (int)strtol(pch, &pch, 10);
-            psc->anCubeMissedDoubleTG[1] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongDoubleDP[0] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongDoubleDP[1] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongDoubleTG[0] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongDoubleTG[1] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongTake[0] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongTake[1] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongPass[0] = (int)strtol(pch, &pch, 10);
-            psc->anCubeWrongPass[1] = (int)strtol(pch, &pch, 10);
+            psc->anCubeMissedDoubleDP[0] = (int) strtol(pch, &pch, 10);
+            psc->anCubeMissedDoubleDP[1] = (int) strtol(pch, &pch, 10);
+            psc->anCubeMissedDoubleTG[0] = (int) strtol(pch, &pch, 10);
+            psc->anCubeMissedDoubleTG[1] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongDoubleDP[0] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongDoubleDP[1] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongDoubleTG[0] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongDoubleTG[1] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongTake[0] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongTake[1] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongPass[0] = (int) strtol(pch, &pch, 10);
+            psc->anCubeWrongPass[1] = (int) strtol(pch, &pch, 10);
 
-            psc->arErrorMissedDoubleDP[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorMissedDoubleDP[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorMissedDoubleTG[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorMissedDoubleTG[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleDP[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleDP[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleTG[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleTG[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongTake[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongTake[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongPass[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongPass[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorMissedDoubleDP[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorMissedDoubleDP[1][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorMissedDoubleTG[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorMissedDoubleTG[1][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleDP[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleDP[1][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleTG[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongDoubleTG[1][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongTake[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongTake[1][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongPass[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arErrorWrongPass[1][1] = (float)g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleDP[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleDP[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleTG[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleTG[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleDP[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleDP[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleTG[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleTG[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongTake[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongTake[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongPass[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongPass[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleDP[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleDP[1][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleTG[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorMissedDoubleTG[1][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleDP[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleDP[1][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleTG[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongDoubleTG[1][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongTake[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongTake[1][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongPass[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arErrorWrongPass[1][1] = (float) g_ascii_strtod(pch, &pch);
 
             break;
 
@@ -295,14 +296,14 @@ RestoreGS(listOLD * pl, statcontext * psc)
             pch += 2;
 
             for (lt = LUCK_VERYBAD; lt <= LUCK_VERYGOOD; lt++) {
-                psc->anLuck[0][lt] = (int)strtol(pch, &pch, 10);
-                psc->anLuck[1][lt] = (int)strtol(pch, &pch, 10);
+                psc->anLuck[0][lt] = (int) strtol(pch, &pch, 10);
+                psc->anLuck[1][lt] = (int) strtol(pch, &pch, 10);
             }
 
-            psc->arLuck[0][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arLuck[0][1] = (float)g_ascii_strtod(pch, &pch);
-            psc->arLuck[1][0] = (float)g_ascii_strtod(pch, &pch);
-            psc->arLuck[1][1] = (float)g_ascii_strtod(pch, &pch);
+            psc->arLuck[0][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arLuck[0][1] = (float) g_ascii_strtod(pch, &pch);
+            psc->arLuck[1][0] = (float) g_ascii_strtod(pch, &pch);
+            psc->arLuck[1][1] = (float) g_ascii_strtod(pch, &pch);
 
             break;
 
@@ -449,7 +450,7 @@ RestoreRootNode(listOLD * pl)
             if (*++pch != '+')
                 continue;
 
-            pmr->g.nPoints = (int)strtol(pch, &pch, 10);
+            pmr->g.nPoints = (int) strtol(pch, &pch, 10);
             if (pmr->g.nPoints < 1)
                 pmr->g.nPoints = 1;
 
@@ -475,9 +476,9 @@ RestoreRootNode(listOLD * pl)
             RestoreText(pp->pl->plNext->p, &mi.pchRating[1]);
         else if (pp->ach[0] == 'D' && pp->ach[1] == 'T') {
             /* DT - Date */
-            int nYear, nMonth, nDay;
+            unsigned int nYear, nMonth, nDay;
 
-            if (pp->pl->plNext->p && sscanf(pp->pl->plNext->p, "%d-%d-%d", &nYear, &nMonth, &nDay) == 3) {
+            if (pp->pl->plNext->p && sscanf(pp->pl->plNext->p, "%u-%u-%u", &nYear, &nMonth, &nDay) == 3) {
                 mi.nYear = nYear;
                 mi.nMonth = nMonth;
                 mi.nDay = nDay;
@@ -525,8 +526,8 @@ RestoreRolloutScore(move * pm, const char *sz)
     if (!pc)
         return;
     pc += 6;
-    pm->rScore = (float)g_ascii_strtod(pc, &pc);
-    pm->rScore2 = (float)g_ascii_strtod(pc, &pc);
+    pm->rScore = (float) g_ascii_strtod(pc, &pc);
+    pm->rScore2 = (float) g_ascii_strtod(pc, &pc);
 }
 
 static void
@@ -560,7 +561,7 @@ RestoreRolloutOutput(float ar[NUM_ROLLOUT_OUTPUTS], const char *sz, const char *
     pc += strlen(szKeyword) + 1;
 
     for (i = 0; i < 7; i++)
-        ar[i] = (float)g_ascii_strtod(pc, &pc);
+        ar[i] = (float) g_ascii_strtod(pc, &pc);
 
 }
 
@@ -582,23 +583,22 @@ RestoreEvalContext(evalcontext * pec, char *pc)
 {
 
     int fUsePrune = 0;
-    int red __attribute((unused)) = 0;
     int ver = CheckSGFVersion(&pc);
 
     InitEvalContext(pec);
-    pec->nPlies = (unsigned int)strtol(pc, &pc, 10);
+    pec->nPlies = (unsigned int) strtol(pc, &pc, 10);
     if (*pc == 'C') {
         pec->fCubeful = TRUE;
         pc++;
     }
     if (ver < 3) {
-        red = (int)strtol(pc, &pc, 10);
-        pec->fDeterministic = (unsigned int)strtol(pc, &pc, 10);
-        pec->rNoise = (float)g_ascii_strtod(pc, &pc);
+        (void) strtol(pc, &pc, 10);     /* reduced evaluation -- no longer supported */
+        pec->fDeterministic = (unsigned int) strtol(pc, &pc, 10);
+        pec->rNoise = (float) g_ascii_strtod(pc, &pc);
     } else {
-        pec->fDeterministic = (unsigned int)strtol(pc, &pc, 10);
-        pec->rNoise = (float)g_ascii_strtod(pc, &pc);
-        fUsePrune = (unsigned int)strtol(pc, &pc, 10);
+        pec->fDeterministic = (unsigned int) strtol(pc, &pc, 10);
+        pec->rNoise = (float) g_ascii_strtod(pc, &pc);
+        fUsePrune = (unsigned int) strtol(pc, &pc, 10);
         pec->fUsePrune = fUsePrune;
     }
 }
@@ -759,9 +759,9 @@ RestoreRolloutMoveFilter(const char *sz, char *name, movefilter mf[MAX_FILTER_PL
 
     pc += strlen(name);
     for (i = 0; i < nPlies; ++i) {
-        mf[nPlies - 1][i].Accept = (int)strtol(pc, &pc, 10);
-        mf[nPlies - 1][i].Extra = (int)strtol(pc, &pc, 10);
-        mf[nPlies - 1][i].Threshold = (float)g_ascii_strtod(pc, &pc);
+        mf[nPlies - 1][i].Accept = (int) strtol(pc, &pc, 10);
+        mf[nPlies - 1][i].Extra = (int) strtol(pc, &pc, 10);
+        mf[nPlies - 1][i].Threshold = (float) g_ascii_strtod(pc, &pc);
     }
 }
 
@@ -865,10 +865,7 @@ RestoreDoubleAnalysis(property * pp,
 {
 
     char *pch = pp->pl->plNext->p;
-    int nReduced __attribute((unused));
     int fUsePrune = 0;
-    /* leftovers from earlier formats */
-    float arUnused[4] __attribute__ ((unused));
     int ver;
     int i, j;
 
@@ -878,7 +875,6 @@ RestoreDoubleAnalysis(property * pp,
         ++pch;
         pes->et = EVAL_EVAL;
         ver = CheckSGFVersion(&pch);
-        nReduced = 0;
         pes->ec.rNoise = 0.0f;
         memset(aarOutput[0], 0, NUM_ROLLOUT_OUTPUTS * sizeof(float));
         memset(aarOutput[1], 0, NUM_ROLLOUT_OUTPUTS * sizeof(float));
@@ -886,43 +882,44 @@ RestoreDoubleAnalysis(property * pp,
         aarOutput[1][OUTPUT_CUBEFUL_EQUITY] = -20000.0;
 
         if (ver < 2) {
-            arUnused[0] = (float)g_ascii_strtod(pch, &pch);
-            arUnused[1] = (float)g_ascii_strtod(pch, &pch);
-            arUnused[2] = (float)g_ascii_strtod(pch, &pch);
-            arUnused[3] = (float)g_ascii_strtod(pch, &pch);
-            pes->ec.nPlies = (unsigned int)strtol(pch, &pch, 10);
+            /* skip 4 fields left over from earlier formats */
+            (void) g_ascii_strtod(pch, &pch);
+            (void) g_ascii_strtod(pch, &pch);
+            (void) g_ascii_strtod(pch, &pch);
+            (void) g_ascii_strtod(pch, &pch);
+            pes->ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
             if (*pch == 'C') {
                 pes->ec.fCubeful = TRUE;
                 pch++;
             }
-            nReduced = (int)strtol(pch, &pch, 10);
-            pes->ec.fDeterministic = (unsigned int)strtol(pch, &pch, 10);
-            pes->ec.rNoise = (float)g_ascii_strtod(pch, &pch);
+            (void) strtol(pch, &pch, 10);       /* reduced evaluation -- no longer supported */
+            pes->ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
+            pes->ec.rNoise = (float) g_ascii_strtod(pch, &pch);
         } else if (ver == 2) {
-            pes->ec.nPlies = (unsigned int)strtol(pch, &pch, 10);
+            pes->ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
             if (*pch == 'C') {
                 pes->ec.fCubeful = TRUE;
                 pch++;
             }
-            nReduced = (int)strtol(pch, &pch, 10);
-            pes->ec.fDeterministic = (unsigned int)strtol(pch, &pch, 10);
-            pes->ec.rNoise = (float)g_ascii_strtod(pch, &pch);
-            fUsePrune = (int)strtol(pch, &pch, 10);
+            (void) strtol(pch, &pch, 10);       /* reduced evaluation -- no longer supported */
+            pes->ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
+            pes->ec.rNoise = (float) g_ascii_strtod(pch, &pch);
+            fUsePrune = (int) strtol(pch, &pch, 10);
         } else {
-            pes->ec.nPlies = (unsigned int)strtol(pch, &pch, 10);
+            pes->ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
             if (*pch == 'C') {
                 pes->ec.fCubeful = TRUE;
                 pch++;
             }
-            pes->ec.fDeterministic = (unsigned int)strtol(pch, &pch, 10);
-            pes->ec.rNoise = (float)g_ascii_strtod(pch, &pch);
-            fUsePrune = (int)strtol(pch, &pch, 10);
+            pes->ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
+            pes->ec.rNoise = (float) g_ascii_strtod(pch, &pch);
+            fUsePrune = (int) strtol(pch, &pch, 10);
         }
         pes->ec.fUsePrune = fUsePrune;
 
         for (i = 0; i < 2; i++)
             for (j = 0; j < 7; j++)
-                aarOutput[i][j] = (float)g_ascii_strtod(pch, &pch);
+                aarOutput[i][j] = (float) g_ascii_strtod(pch, &pch);
         break;
 
     case 'R':
@@ -948,7 +945,7 @@ RestoreMarkedMoves(property * pp, movelist * pml)
 {
     int val;
     char *pch = pp->pl->plNext->p;
-    while ((val = (int)strtol(pch, &pch, 10))) {
+    while ((val = (int) strtol(pch, &pch, 10))) {
         if (val > (int) pml->cMoves || val < 1)
             continue;
         pml->amMoves[val - 1].cmark = CMARK_ROLLOUT;
@@ -960,13 +957,9 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
                     movelist * pml, unsigned int *piMove, evalsetup * pesChequer, const matchstate * pms)
 {
     listOLD *pl = pp->pl->plNext;
-    const char *pc;
-    char *pch;
-    char ch;
+    char *pc, *pch, ch;
     move *pm;
     int i;
-    int fDeterministic __attribute((unused));
-    int nReduced __attribute((unused));
     int fUsePrune = 0;
     TanBoard anBoardMove;
     int ver;
@@ -1009,7 +1002,7 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
         ApplyMove(anBoardMove, pm->anMove, FALSE);
         PositionKey((ConstTanBoard) anBoardMove, &pm->key);
 
-        pch = (char *) pc;
+        pch = pc;
         while (isspace(ch = *pch++)) {
         };
         pch++;
@@ -1019,41 +1012,38 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
             ver = CheckSGFVersion(&pch);
             /* EVAL_EVAL */
             pm->esMove.et = EVAL_EVAL;
-            nReduced = 0;
-            fDeterministic = 0;
             for (i = 0; i < 5; i++)
-                pm->arEvalMove[i] = (float)g_ascii_strtod(pch, &pch);
-            pm->rScore = (float)g_ascii_strtod(pch, &pch);
+                pm->arEvalMove[i] = (float) g_ascii_strtod(pch, &pch);
+            pm->rScore = (float) g_ascii_strtod(pch, &pch);
             if (ver < 2) {
-                pm->esMove.ec.nPlies = (unsigned int)strtol(pch, &pch, 10);
+                pm->esMove.ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
                 if (*pch == 'C') {
                     pm->esMove.ec.fCubeful = TRUE;
                     pch++;
                 }
-                nReduced = (int)strtol(pch, &pch, 10);
-                pm->esMove.ec.fDeterministic = (unsigned int)strtol(pch, &pch, 10);
-                pm->esMove.ec.rNoise = (float)g_ascii_strtod(pch, &pch);
+                (void) strtol(pch, &pch, 10);   /* reduced evaluation -- no longer supported */
+                pm->esMove.ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
+                pm->esMove.ec.rNoise = (float) g_ascii_strtod(pch, &pch);
             } else if (ver == 2) {
-                pm->esMove.ec.nPlies = (unsigned int)strtol(pch, &pch, 10);
+                pm->esMove.ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
                 if (*pch == 'C') {
                     pm->esMove.ec.fCubeful = TRUE;
                     pch++;
                 }
-                nReduced = (int)strtol(pch, &pch, 10);
-                pm->esMove.ec.fDeterministic = (unsigned int)strtol(pch, &pch, 10);
-                pm->esMove.ec.rNoise = (float)g_ascii_strtod(pch, &pch);
-                fUsePrune = (int)strtol(pch, &pch, 10);
+                (void) strtol(pch, &pch, 10);   /* reduced evaluation -- no longer supported */
+                pm->esMove.ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
+                pm->esMove.ec.rNoise = (float) g_ascii_strtod(pch, &pch);
+                fUsePrune = (int) strtol(pch, &pch, 10);
             } else {
-                pm->esMove.ec.nPlies = (unsigned int)strtol(pch, &pch, 10);
+                pm->esMove.ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
                 if (*pch == 'C') {
                     pm->esMove.ec.fCubeful = TRUE;
                     pch++;
                 }
-                /* FIXME: reduced shouldn't be saved/loaded */
-                nReduced = (int)strtol(pch, &pch, 10);
-                pm->esMove.ec.fDeterministic = (unsigned int)strtol(pch, &pch, 10);
-                pm->esMove.ec.rNoise = (float)g_ascii_strtod(pch, &pch);
-                fUsePrune = (int)strtol(pch, &pch, 10);
+                (void) strtol(pch, &pch, 10);   /* reduced evaluation -- no longer supported */
+                pm->esMove.ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
+                pm->esMove.ec.rNoise = (float) g_ascii_strtod(pch, &pch);
+                fUsePrune = (int) strtol(pch, &pch, 10);
             }
             pm->esMove.ec.fUsePrune = fUsePrune;
             break;
@@ -1274,7 +1264,7 @@ RestoreNode(listOLD * pl)
         else if (pp->ach[0] == 'D' && pp->ach[1] == 'C')
             ast[1] = SKILL_DOUBTFUL;
         else if (pp->ach[0] == 'L' && pp->ach[1] == 'U')
-            rLuck = (float)g_ascii_strtod(pp->pl->plNext->p, NULL);
+            rLuck = (float) g_ascii_strtod(pp->pl->plNext->p, NULL);
         else if (pp->ach[0] == 'G' && pp->ach[1] == 'B')
             /* good for black */
             lt = *((char *) pp->pl->plNext->p) == '2' ? LUCK_VERYGOOD : LUCK_GOOD;
@@ -1633,7 +1623,7 @@ WriteRolloutContext(FILE * pf, rolloutcontext * prc)
 
     int i;
 
-    fprintf(pf, "RC %u %u %u %u %u %u %d %u %u %d \"%s\" %lu ",
+    fprintf(pf, "RC %u %u %u %u %u %u %u %u %u %u \"%s\" %lu ",
             prc->fCubeful,
             prc->fVarRedn,
             prc->fInitial,
@@ -1853,7 +1843,7 @@ WriteMoveAnalysis(FILE * pf, int fPlayer, movelist * pml, unsigned int iMove)
     fprintf(pf, "MR[");
     for (i = 0; i < pml->cMoves; i++) {
         if (pml->amMoves[i].cmark)
-            fprintf(pf, "%d ", i + 1);
+            fprintf(pf, "%u ", i + 1);
     }
     fputc(']', pf);
 }
@@ -2243,7 +2233,7 @@ SaveGame(FILE * pf, listOLD * plGame)
                 fputs("AW", pf);
                 for (i = 0; i < 25; i++)
                     for (j = 0; j < anBoard[1][i]; j++)
-                        fprintf(pf, "[%c]", 'a' + i);
+                        fprintf(pf, "[%c]", (char) ('a' + i));
             }
 
             for (i = 0, j = 0; i < 25; ++i)
@@ -2253,7 +2243,7 @@ SaveGame(FILE * pf, listOLD * plGame)
                 fputs("AB", pf);
                 for (i = 0; i < 25; i++)
                     for (j = 0; j < anBoard[0][i]; j++)
-                        fprintf(pf, "[%c]", i == 24 ? 'y' : 'x' - i);
+                        fprintf(pf, "[%c]", i == 24 ? 'y' : (char) ('x' - i));
             }
 
             break;
@@ -2317,7 +2307,7 @@ CommandSaveGame(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -2357,7 +2347,7 @@ CommandSaveMatch(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -2403,7 +2393,7 @@ CommandSavePosition(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = g_fopen(sz, "w"))) {
+    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
