@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: text.c,v 1.109 2014/02/12 21:13:53 plm Exp $
+ * $Id: text.c,v 1.111 2015/09/26 20:20:13 plm Exp $
  */
 
 #include "config.h"
@@ -28,6 +28,7 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <stdarg.h>
+#include "glib-ext.h"
 
 #include "backgammon.h"
 #include "drawboard.h"
@@ -223,7 +224,7 @@ TextEpilogue(FILE * pf, const matchstate * UNUSED(pms))
 
     time_t t;
 
-    const char szVersion[] = "$Revision: 1.109 $";
+    const char szVersion[] = "$Revision: 1.111 $";
     int iMajor, iMinor;
 
     iMajor = atoi(strchr(szVersion, ' '));
@@ -407,7 +408,7 @@ TextPrintMoveAnalysis(GString * gsz, const matchstate * pms, moverecord * pmr)
 
         g_string_append_printf(gsz, _("Alert: %s move"), gettext(aszSkillType[pmr->n.stMove]));
 
-        if (!pms->nMatchTo || (pms->nMatchTo && !fOutputMWC))
+        if (!pms->nMatchTo || !fOutputMWC)
             g_string_append_printf(gsz, " (%+7.3f)\n",
                                    pmr->ml.amMoves[pmr->n.iMove].rScore - pmr->ml.amMoves[0].rScore);
         else
@@ -424,7 +425,7 @@ TextPrintMoveAnalysis(GString * gsz, const matchstate * pms, moverecord * pmr)
 
         g_string_append_printf(gsz, _("Alert: %s roll!"), gettext(aszLuckType[pmr->lt]));
 
-        if (!pms->nMatchTo || (pms->nMatchTo && !fOutputMWC))
+        if (!pms->nMatchTo || !fOutputMWC)
             g_string_append_printf(gsz, " (%+7.3f)\n", pmr->rLuck);
         else
             g_string_append_printf(gsz, " (%+6.3f%%)\n", 100.0f * eq2mwc(pmr->rLuck, &ci) - 100.0f * eq2mwc(0.0f, &ci));
@@ -814,7 +815,7 @@ CommandExportGameText(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if ((pf = g_fopen(sz, "w")) == 0) {
+    else if ((pf = gnubg_g_fopen(sz, "w")) == 0) {
         outputerr(sz);
         return;
     }
@@ -864,7 +865,7 @@ CommandExportMatchText(char *sz)
 
         if (!strcmp(szCurrent, "-"))
             pf = stdout;
-        else if ((pf = g_fopen(szCurrent, "w")) == 0) {
+        else if ((pf = gnubg_g_fopen(szCurrent, "w")) == 0) {
             outputerr(szCurrent);
             return;
         }
@@ -908,7 +909,7 @@ CommandExportPositionText(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if ((pf = g_fopen(sz, "w")) == 0) {
+    else if ((pf = gnubg_g_fopen(sz, "w")) == 0) {
         outputerr(sz);
         return;
     }
